require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_aadconditionalaccesspolicy',
  dscmeta_resource_friendly_name: 'AADConditionalAccessPolicy',
  dscmeta_resource_name: 'MSFT_AADConditionalAccessPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC AADConditionalAccessPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_persistentbrowserisenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies, whether Browser Persistence is controlled by the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_includeapplications: {
      type: 'Optional[Array[String]]',
      desc: 'Cloud Apps in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_includeroles: {
      type: 'Optional[Array[String]]',
      desc: 'AAD Admin Roles in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'DisplayName of the AAD CA Policy',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationenforcedrestrictionsisenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies, whether Application Enforced Restrictions are enabled in the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_excludeusers: {
      type: 'Optional[Array[String]]',
      desc: 'Users out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_grantcontroloperator: {
      type: "Optional[Enum['AND', 'OR']]",
      desc: 'Operator to be used for Grant Controls.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cloudappsecurityisenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies, whether Cloud App Security is enforced by the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_signinfrequencyisenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies, whether sign-in frequency is enforced by the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_persistentbrowsermode: {
      type: "Optional[Enum['Always', 'Never', '']]",
      desc: 'Specifies, what Browser Persistence control is enforced by the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials for the Microsoft Graph delegated permissions.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_includeplatforms: {
      type: 'Optional[Array[String]]',
      desc: 'Client Device Platforms in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_excludegroups: {
      type: 'Optional[Array[String]]',
      desc: 'Groups out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_excludelocations: {
      type: 'Optional[Array[String]]',
      desc: 'AAD Named Locations out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_userrisklevels: {
      type: 'Optional[Array[String]]',
      desc: 'AAD Identity Protection User Risk Levels in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_termsofuse: {
      type: 'Optional[String]',
      desc: 'Display name of the terms of use to assign.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_builtincontrols: {
      type: 'Optional[Array[String]]',
      desc: 'List of built-in Grant Controls to be applied by the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_includeuseractions: {
      type: 'Optional[Array[String]]',
      desc: 'User Actions in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if the Azure AD CA Policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_includedevices: {
      type: 'Optional[Array[String]]',
      desc: 'Client Device Compliance states in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_id: {
      type: 'Optional[String]',
      desc: 'Specifies the GUID for the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cloudappsecuritytype: {
      type: 'Optional[String]',
      desc: 'Specifies, what Cloud App Security control is enforced by the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signinrisklevels: {
      type: 'Optional[Array[String]]',
      desc: 'AAD Identity Protection Sign-in Risk Levels in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_excluderoles: {
      type: 'Optional[Array[String]]',
      desc: 'AAD Admin Roles out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_excludedevices: {
      type: 'Optional[Array[String]]',
      desc: 'Client Device Compliance states out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_signinfrequencytype: {
      type: "Optional[Enum['Days', 'Hours', '']]",
      desc: 'Sign in frequency unit (days/hours) to be interpreted by the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signinfrequencyvalue: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Sign in frequency time in the given unit to be enforced by the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_excludeapplications: {
      type: 'Optional[Array[String]]',
      desc: 'Cloud Apps out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['disabled', 'enabled', 'enabledForReportingButNotEnforced']]",
      desc: 'Specifies the State of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_excludeplatforms: {
      type: 'Optional[Array[String]]',
      desc: 'Client Device Platforms out of scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_clientapptypes: {
      type: 'Optional[Array[String]]',
      desc: 'Client App types in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_includelocations: {
      type: 'Optional[Array[String]]',
      desc: 'AAD Named Locations in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_includeusers: {
      type: 'Optional[Array[String]]',
      desc: 'Users in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_includegroups: {
      type: 'Optional[Array[String]]',
      desc: 'Groups in scope of the Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
