require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_aadgroupssettings',
  dscmeta_resource_friendly_name: 'AADGroupsSettings',
  dscmeta_resource_name: 'MSFT_AADGroupsSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC AADGroupsSettings resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_groupcreationallowedgroupname: {
      type: 'Optional[String]',
      desc: 'Name of the security group for which the members are allowed to create Office 365 groups even when EnableGroupCreation == false.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablegroupcreation: {
      type: 'Optional[Boolean]',
      desc: 'The flag indicating whether Office 365 group creation is allowed in the directory by non-admin users. This setting does not require an Azure Active Directory Premium P1 license.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowgueststoaccessgroups: {
      type: 'Optional[Boolean]',
      desc: 'Boolean indicating whether or not a guest user can have access to Office 365 groups content. This setting does not require an Azure Active Directory Premium P1 license.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials for the Microsoft Graph delegated permissions.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_guestusageguidelinesurl: {
      type: 'Optional[String]',
      desc: 'The url of a link to the guest usage guidelines.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if the Azure AD Groups Naming Policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usageguidelinesurl: {
      type: 'Optional[String]',
      desc: 'A link to the Group Usage Guidelines.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Only valid value is 'Yes'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowgueststobegroupowner: {
      type: 'Optional[Boolean]',
      desc: 'Boolean indicating whether or not a guest user can be an owner of groups.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowtoaddguests: {
      type: 'Optional[Boolean]',
      desc: 'A boolean indicating whether or not is allowed to add guests to this directory.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
