require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_exoantiphishpolicy',
  dscmeta_resource_friendly_name: 'EXOAntiPhishPolicy',
  dscmeta_resource_name: 'MSFT_EXOAntiPhishPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC EXOAntiPhishPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enablefirstcontactsafetytips: {
      type: 'Optional[Boolean]',
      desc: "The EnableFirstContactSafetyTips parameter specifies whether to enable or disable the safety tip that's shown when recipients first receive an email from a sender or do not often receive email from a sender.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablemailboxintelligenceprotection: {
      type: 'Optional[Boolean]',
      desc: "The EnableMailboxIntelligenceProtection specifies whether to enable or disable enhanced impersonation results based on each user's individual sender map. This intelligence allows Microsoft 365 to customize user impersonation detection and better handle false positives.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_phishthresholdlevel: {
      type: "Optional[Enum['1', '2', '3', '4']]",
      desc: "The PhishThresholdLevel parameter specifies the tolerance level that's used by machine learning in the handling of phishing messages.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabletargeteddomainsprotection: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableTargetedDomainsProtection parameter specifies whether to enable domain impersonation protection for a list of specified domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: 'The Identity parameter specifies the name of the antiphishing policy that you want to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Specify if this policy should be enabled. Default is $true.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableviatag: {
      type: 'Optional[Boolean]',
      desc: 'This setting is part of spoof protection. Theâ?¯EnableViaTagâ?¯parameter enables or disables adding the via tag to the From address in Outlook.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mailboxintelligenceprotectionaction: {
      type: 'Optional[String]',
      desc: 'The MailboxIntelligenceProtectionAction parameter specifies what to do with messages that fail mailbox intelligence protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for CertificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_targeteduserstoprotect: {
      type: 'Optional[Array[String]]',
      desc: 'The TargetedUsersToProtect parameter specifies the users that are included in user impersonation protection when the EnableTargetedUserProtection parameter is set to $true.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablespoofintelligence: {
      type: 'Optional[Boolean]',
      desc: 'The EnableSpoofIntelligence parameter specifies whether to enable or disable antispoofing protection for the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablesimilaruserssafetytips: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableSimilarUsersSafetyTipsâ?¯parameter specifies whether to enable safety tips that are shown to recipients in messages for user impersonation detections.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_excludeddomains: {
      type: 'Optional[Array[String]]',
      desc: 'Theâ?¯ExcludedDomainsâ?¯parameter specifies trusted domains that are excluded from scanning by antiphishing protection. You can specify multiple domains separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_admindisplayname: {
      type: 'Optional[String]',
      desc: 'The AdminDisplayName parameter specifies a description for the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableantispoofenforcement: {
      type: 'Optional[Boolean]',
      desc: 'The EnableAntispoofEnforcement parameter specifies whether to enable or disable antispoofing protection for the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_targeteddomainactionrecipients: {
      type: 'Optional[Array[String]]',
      desc: 'Theâ?¯TargetedDomainActionRecipients parameter specifies the recipients to add to detected domain impersonation messages when the TargetedDomainProtectionAction parameter is set to the valueâ?¯Redirect or BccMessage. A valid value for this parameter is an email address. You can specify multiple email addresses separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablemailboxintelligence: {
      type: 'Optional[Boolean]',
      desc: 'The EnableMailboxIntelligence parameter specifies whether to enable or disable mailbox intelligence (the first contact graph) in domain and user impersonation protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_impersonationprotectionstate: {
      type: 'Optional[String]',
      desc: 'The ImpersonationProtectionState parameter specifies the configuration of impersonation protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_targeteddomainprotectionaction: {
      type: "Optional[Enum['BccMessage', 'Delete', 'MoveToJmf', 'NoAction', 'Quarantine', 'Redirect']]",
      desc: 'The TargetedDomainProtectionActionâ?¯parameter specifies the action to take on detected domain impersonation messages for the domains specified by the TargetedDomainsToProtect parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authenticationfailaction: {
      type: "Optional[Enum['MoveToJmf', 'Quarantine']]",
      desc: 'The AuthenticationFailAction parameter specifies the action to take when the message fails composite authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_targeteduserprotectionaction: {
      type: "Optional[Enum['BccMessage', 'Delete', 'MoveToJmf', 'NoAction', 'Quarantine', 'Redirect']]",
      desc: 'The TargetedUserProtectionActionâ?¯parameter specifies the action to take on detected user impersonation messages for the users specified by the TargetedUsersToProtect parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mailboxintelligenceprotectionactionrecipients: {
      type: 'Optional[Array[String]]',
      desc: 'Theâ?¯MailboxIntelligenceProtectionActionRecipients parameter specifies the recipients to add to detected messages when the MailboxIntelligenceProtectionAction parameter is set to the valueâ?¯Redirect or BccMessage.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_makedefault: {
      type: 'Optional[Boolean]',
      desc: 'Make this the default antiphishing policy',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_targeteddomainstoprotect: {
      type: 'Optional[Array[String]]',
      desc: 'The TargetedDomainsToProtect parameter specifies the domains that are included in domain impersonation protection when the EnableTargetedDomainsProtection parameter is set to $true.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enablesimilardomainssafetytips: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableSimilarDomainsSafetyTipsâ?¯parameter specifies whether to enable safety tips that are shown to recipients in messages for domain impersonation detections.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enabletargeteduserprotection: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableTargetedUserProtection parameter specifies whether to enable user impersonation protection for the users specified by the TargetedUsersToProtect parameter',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableunauthenticatedsender: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableUnauthenticatedSenderâ?¯parameter enables or disables unauthenticated sender identification in Outlook.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableorganizationdomainsprotection: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableOrganizationDomainsProtection parameter specifies whether to enable domain impersonation protection for all registered domains in the Office 365 organization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableunusualcharacterssafetytips: {
      type: 'Optional[Boolean]',
      desc: 'Theâ?¯EnableUnusualCharactersSafetyTipsâ?¯parameter specifies whether to enable safety tips that are shown to recipients in messages for unusual characters in domain and user impersonation detections.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_targeteduseractionrecipients: {
      type: 'Optional[Array[String]]',
      desc: 'Theâ?¯TargetedUserActionRecipients parameter specifies the replacement or additional recipients for detected user impersonation messages when the TargetedUserProtectionAction parameter is set to the valueâ?¯Redirect or BccMessage. A valid value for this parameter is an email address. You can specify multiple email addresses separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_excludedsenders: {
      type: 'Optional[Array[String]]',
      desc: 'Theâ?¯ExcludedSendersâ?¯parameter specifies a list of trusted sender email addresses that are excluded from scanning by antiphishing protection. You can specify multiple email addresses separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
