require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_exomobiledevicemailboxpolicy',
  dscmeta_resource_friendly_name: 'EXOMobileDeviceMailboxPolicy',
  dscmeta_resource_name: 'MSFT_EXOMobileDeviceMailboxPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC EXOMobileDeviceMailboxPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_allowsimplepassword: {
      type: 'Optional[Boolean]',
      desc: 'The AllowSimplePassword parameter specifies whether a simple device password is allowed. A simple device password is a password that has a specific pattern, such as 1111 or 1234.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowbluetooth: {
      type: "Optional[Enum['Disable', 'HandsfreeOnly', 'Allow']]",
      desc: 'The AllowBluetooth parameter specifies whether the Bluetooth capabilities are allowed on the mobile phone. The available options are Disable, HandsfreeOnly, and Allow. The default value is Allow.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requireencryptedsmimemessages: {
      type: 'Optional[Boolean]',
      desc: 'The RequireEncryptedSMIMEMessages parameter specifies whether the mobile device must send encrypted S/MIME messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PasswordEnabled parameter specifies whether a password is required on the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_uncaccessenabled: {
      type: 'Optional[Boolean]',
      desc: 'The UNCAccessEnabled parameter specifies whether access to Microsoft Windows file shares is enabled from the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxattachmentsize: {
      type: 'Optional[String]',
      desc: 'The MaxAttachmentSize parameter specifies the maximum size of attachments that can be downloaded to the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowdesktopsync: {
      type: 'Optional[Boolean]',
      desc: 'The AllowDesktopSync parameter specifies whether the mobile phone can synchronize with a desktop computer through a cable.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowgooglepushnotifications: {
      type: 'Optional[Boolean]',
      desc: 'The AllowGooglePushNotifications parameter controls whether the user can receive push notifications from Google for Outlook on the web for devices.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowsmimesoftcerts: {
      type: 'Optional[Boolean]',
      desc: 'The AllowSMIMESoftCerts parameter specifies whether S/MIME software certificates are allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if the Mobile Device Mailbox Policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the friendly name of the mobile device mailbox policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowexternaldevicemanagement: {
      type: 'Optional[Boolean]',
      desc: 'The AllowExternalDeviceManagement parameter specifies whether an external device management program is allowed to manage the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for CertificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_minpasswordlength: {
      type: 'Optional[String]',
      desc: 'The MinPasswordLength parameter specifies the minimum number of characters in the mobile device password.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowconsumeremail: {
      type: 'Optional[Boolean]',
      desc: 'The AllowConsumerEmail parameter specifies whether the mobile phone user can configure a personal email account on the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requiresignedsmimemessages: {
      type: 'Optional[Boolean]',
      desc: 'The RequireSignedSMIMEMessages parameter specifies whether the mobile device must send signed S/MIME messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxcalendaragefilter: {
      type: "Optional[Enum['All', 'TwoWeeks', 'OneMonth', 'ThreeMonths', 'SixMonths']]",
      desc: 'The MaxCalendarAgeFilter parameter specifies the maximum range of calendar days that can be synchronized to the device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isdefault: {
      type: 'Optional[Boolean]',
      desc: 'The IsDefault parameter specifies whether this policy is the default Mobile Device mailbox policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowunsignedinstallationpackages: {
      type: 'Optional[Boolean]',
      desc: 'The AllowUnsignedInstallationPackages parameter specifies whether unsigned installation packages can be executed on the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxemailagefilter: {
      type: "Optional[Enum['All', 'OneDay', 'ThreeDays', 'OneWeek', 'TwoWeeks', 'OneMonth']]",
      desc: 'The MaxEmailAgeFilter parameter specifies the maximum number of days of email items to synchronize to the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowwifi: {
      type: 'Optional[Boolean]',
      desc: 'The AllowWiFi parameter specifies whether wireless Internet access is allowed on the mobile phone. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowirda: {
      type: 'Optional[Boolean]',
      desc: 'The AllowIrDA parameter specifies whether infrared connections are allowed to the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowremotedesktop: {
      type: 'Optional[Boolean]',
      desc: 'The AllowRemoteDesktop parameter specifies whether the mobile phone can initiate a remote desktop connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_alphanumericpasswordrequired: {
      type: 'Optional[Boolean]',
      desc: 'The AlphanumericPasswordRequired parameter specifies whether the password for the mobile phone must be alphanumeric.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requirestoragecardencryption: {
      type: 'Optional[Boolean]',
      desc: 'The RequireStorageCardEncryption parameter specifies whether storage card encryption is required on the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordhistory: {
      type: 'Optional[String]',
      desc: 'The PasswordHistory parameter specifies the number of unique new passwords that need to be created on the mobile device before an old password can be reused.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allownonprovisionabledevices: {
      type: 'Optional[Boolean]',
      desc: 'The AllowNonProvisionableDevices parameter specifies whether all mobile phones can synchronize with the server running Exchange.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowtextmessaging: {
      type: 'Optional[Boolean]',
      desc: 'The AllowTextMessaging parameter specifies whether text messaging is allowed from the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_maxemailhtmlbodytruncationsize: {
      type: 'Optional[String]',
      desc: 'The MaxEmailHTMLBodyTruncationSize parameter specifies the maximum size at which HTML-formatted email messages are synchronized to the mobile phone. The value is specified in KB.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowmobileotaupdate: {
      type: 'Optional[Boolean]',
      desc: 'The AllowMobileOTAUpdate parameter specifies whether the Exchange ActiveSync mailbox policy can be sent to the mobile phone over a cellular data connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowapplepushnotifications: {
      type: 'Optional[Boolean]',
      desc: 'The AllowApplePushNotifications parameter specifies whether push notifications are allowed to Apple mobile devices.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_unapprovedinromapplicationlist: {
      type: 'Optional[Array[String]]',
      desc: "The UnapprovedInROMApplicationList parameter specifies a list of applications that can't be run in ROM on the mobile device.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_approvedapplicationlist: {
      type: 'Optional[Array[String]]',
      desc: 'The ApprovedApplicationList parameter specifies a list of approved applications for the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_requiredeviceencryption: {
      type: 'Optional[Boolean]',
      desc: 'The RequireDeviceEncryption parameter specifies whether encryption is required on the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowpopimapemail: {
      type: 'Optional[Boolean]',
      desc: 'The AllowPOPIMAPEmail parameter specifies whether the user can configure a POP3 or IMAP4 email account on the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowinternetsharing: {
      type: 'Optional[Boolean]',
      desc: 'The AllowInternetSharing parameter specifies whether the mobile phone can be used as a modem to connect a computer to the Internet.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_deviceencryptionenabled: {
      type: 'Optional[Boolean]',
      desc: 'The DeviceEncryptionEnabled parameter specifies whether encryption is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxpasswordfailedattempts: {
      type: 'Optional[String]',
      desc: 'The MaxPasswordFailedAttempts parameter specifies the number of attempts a user can make to enter the correct password for the mobile phone. You can enter any number from 4 through 16 or the value Unlimited.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requireencryptionsmimealgorithm: {
      type: "Optional[Enum['DES', 'TripleDES', 'RC240bit', 'RC264bit', 'RC2128bit']]",
      desc: "The RequireEncryptionSMIMEAlgorithm parameter specifies the algorithm that's required to encrypt S/MIME messages on a mobile device.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_minpasswordcomplexcharacters: {
      type: 'Optional[String]',
      desc: 'The MinPasswordComplexCharacters parameter specifies the character sets that are required in the password of the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowcamera: {
      type: 'Optional[Boolean]',
      desc: "The AllowCamera parameter specifies whether the mobile phone's camera is allowed.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requiremanualsyncwhenroaming: {
      type: 'Optional[Boolean]',
      desc: "The RequireSignedSMIMEAlgorithm parameter specifies the algorithm that's used to sign S/MIME messages on the mobile device.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_irmenabled: {
      type: 'Optional[Boolean]',
      desc: 'The IrmEnabled parameter specifies whether Information Rights Management (IRM) is enabled for the mailbox policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wssaccessenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WSSAccessEnabled parameter specifies whether access to Microsoft Windows SharePoint Services is enabled from the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordexpiration: {
      type: 'Optional[String]',
      desc: 'The PasswordExpiration parameter specifies how long a password can be used on a mobile device before the user is forced to change the password.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devicepolicyrefreshinterval: {
      type: 'Optional[String]',
      desc: 'The DevicePolicyRefreshInterval parameter specifies how often the policy is sent from the server to the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxemailbodytruncationsize: {
      type: 'Optional[String]',
      desc: 'The MaxEmailBodyTruncationSize parameter specifies the maximum size at which email messages are truncated when synchronized to the mobile phone. The value is specified in kilobytes (KB).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowunsignedapplications: {
      type: 'Optional[Boolean]',
      desc: 'The AllowUnsignedApplications parameter specifies whether unsigned applications can be installed on the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_attachmentsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The AttachmentsEnabled parameter specifies whether attachments can be downloaded.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordrecoveryenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PasswordRecoveryEnabled parameter specifies whether the recovery password for the mobile device is stored in Exchange.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowstoragecard: {
      type: 'Optional[Boolean]',
      desc: 'The AllowStorageCard parameter specifies whether the mobile phone can access information stored on a storage card.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowbrowser: {
      type: 'Optional[Boolean]',
      desc: "The AllowBrowser parameter indicates whether Microsoft Pocket Internet Explorer is allowed on the mobile phone. This parameter doesn't affect third-party browsers.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowmicrosoftpushnotifications: {
      type: 'Optional[Boolean]',
      desc: 'The AllowMicrosoftPushNotifications parameter specifies whether push notifications are enabled on the mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maxinactivitytimelock: {
      type: 'Optional[String]',
      desc: 'The MaxInactivityTimeDeviceLock parameter specifies the length of time that the mobile phone can be inactive before the password is required to reactivate it.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowsmimeencryptionalgorithmnegotiation: {
      type: "Optional[Enum['AllowAnyAlgorithmNegotiation', 'BlockNegotiation', 'OnlyStrongAlgorithmNegotiation']]",
      desc: "The AllowSMIMEEncryptionAlgorithmNegotiation parameter specifies whether the messaging application on the mobile device can negotiate the encryption algorithm if a recipient's certificate doesn't support the specified encryption algorithm.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requiresignedsmimealgorithm: {
      type: "Optional[Enum['SHA1', 'MD5']]",
      desc: "The RequireSignedSMIMEAlgorithm parameter specifies the algorithm that's used to sign S/MIME messages on the mobile device.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowhtmlemail: {
      type: 'Optional[Boolean]',
      desc: 'The AllowHTMLEmail parameter specifies whether HTML email is enabled on the mobile phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
