require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_exoowamailboxpolicy',
  dscmeta_resource_friendly_name: 'EXOOwaMailboxPolicy',
  dscmeta_resource_name: 'MSFT_EXOOwaMailboxPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC EXOOwaMailboxPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_personalaccountcalendarsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PersonalAccountCalendarsEnabled parameter specifies whether to allow users to connect to their personal Outlook.com or Google Calendar in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_explicitlogonenabled: {
      type: 'Optional[Boolean]',
      desc: "The ExplicitLogonEnabled parameter specifies whether to allow a user to open someone else's mailbox in Outlook on the web (provided that user has permissions to the mailbox).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_blockedfiletypes: {
      type: 'Optional[Array[String]]',
      desc: "The BlockedFileTypes parameter specifies a list of attachment file types (file extensions) that can't be saved locally or viewed from Outlook on the web.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_conditionalaccesspolicy: {
      type: "Optional[Enum['Off', 'ReadOnly', 'ReadOnlyPlusAttachmentsBlocked']]",
      desc: 'The ConditionalAccessPolicy parameter specifies the Outlook on the Web Policy for limited access. For this feature to work properly, you also need to configure a Conditional Access policy in the Azure Active Directory Portal.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_signaturesenabled: {
      type: 'Optional[Boolean]',
      desc: 'The SignaturesEnabled parameter specifies whether to enable or disable the use of signatures in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowedmimetypes: {
      type: 'Optional[Array[String]]',
      desc: 'The AllowedMimeTypes parameter specifies the MIME extensions of attachments that allow the attachments to be saved locally or viewed from Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_weatherenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WeatherEnabled parameter specifies whether to enable or disable weather information in the calendar in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wacviewingonpubliccomputersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WacViewingOnPublicComputersEnabled parameter specifies whether to enable or disable web viewing of supported Office documents in public computer sessions in Office Online Server. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_outlookbetatoggleenabled: {
      type: 'Optional[Boolean]',
      desc: 'The OutlookBetaToggleEnabled parameter specifies whether to enable or disable the Outlook on the web Preview toggle. The Preview toggle allows users to try the new Outlook on the web experience.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_externalspmysitehosturl: {
      type: 'Optional[String]',
      desc: 'The ExternalSPMySiteHostURL specifies the My Site Host URL for external users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_onsendaddinsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The OnSendAddinsEnabled parameter specifies whether to enable or disable on send add-ins in Outlook on the web (add-ins that support events when a user clicks Send).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_notesenabled: {
      type: 'Optional[Boolean]',
      desc: 'The NotesEnabled parameter specifies whether the Notes folder is available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_journalenabled: {
      type: 'Optional[Boolean]',
      desc: 'The JournalEnabled parameter specifies whether the Journal folder is available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displayphotosenabled: {
      type: 'Optional[Boolean]',
      desc: 'The DisplayPhotosEnabled parameter specifies whether users see sender photos in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_groupcreationenabled: {
      type: 'Optional[Boolean]',
      desc: 'The GroupCreationEnabled parameter specifies whether Office 365 group creation is available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_forcesavefiletypes: {
      type: 'Optional[Array[String]]',
      desc: 'The ForceSaveFileTypes parameter specifies the attachment file types (file extensions) that can only be saved from Outlook on the web (not opened).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_forcewacviewingfirstonpubliccomputers: {
      type: 'Optional[Boolean]',
      desc: 'The ForceWacViewingFirstOnPublicComputers parameter specifies whether public computers must first preview an Office file as a web page in Office Online Server before opening the file in the local application.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_placesenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PlacesEnabled parameter specifies whether to enable or disable Places in Outlook on the web. Places lets users search, share, and map location details by using Bing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_teamsnapcalendarsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The TeamSnapCalendarsEnabled parameter specifies whether to allow users to connect to their personal TeamSnap calendars in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wacviewingonprivatecomputersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WacViewingOnPrivateComputersEnabled parameter specifies whether to enable or disable web viewing of supported Office documents private computer sessions in Office Online Server (formerly known as Office Web Apps Server and Web Access Companion Server). By default, all Outlook on the web sessions are considered to be on private computers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_textmessagingenabled: {
      type: 'Optional[Boolean]',
      desc: 'The TextMessagingEnabled parameter specifies whether users can send and receive text messages in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchfoldersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The SearchFoldersEnabled parameter specifies whether Search Folders are available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_uservoiceenabled: {
      type: 'Optional[Boolean]',
      desc: "The UserVoiceEnabled parameter specifies whether to enable or disable Outlook UserVoice in Outlook on the web. Outlook UserVoice is a customer feedback area that's available in Office 365.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_globaladdresslistenabled: {
      type: 'Optional[Boolean]',
      desc: 'The GlobalAddressListEnabled parameter specifies whether the global address list is available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_irmenabled: {
      type: 'Optional[Boolean]',
      desc: 'The IRMEnabled parameter specifies whether Information Rights Management (IRM) features are available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if the OWA Mailbox Policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_directfileaccessonpubliccomputersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The DirectFileAccessOnPrivateComputersEnabled parameter specifies the left-click options for attachments in Outlook on the web for public computer sessions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_directfileaccessonprivatecomputersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The DirectFileAccessOnPrivateComputersEnabled parameter specifies the left-click options for attachments in Outlook on the web for private computer sessions. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for CertificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_npssurveysenabled: {
      type: 'Optional[Boolean]',
      desc: 'The NpsSurveysEnabled parameter specifies whether to enable or disable the Net Promoter Score (NPS) survey in Outlook on the web. The survey allows uses to rate Outlook on the web on a scale of 1 to 5, and to provide feedback and suggested improvements in free text.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_forcesavemimetypes: {
      type: 'Optional[Array[String]]',
      desc: 'The ForceSaveMimeTypes parameter specifies the MIME extensions in attachments that only allow the attachments to be saved locally (not opened).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_wacomexenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WacOMEXEnabled parameter specifies whether to enable or disable apps for Outlook in Outlook on the web in Office Online Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wacexternalservicesenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WacExternalServicesEnabled parameter specifies whether to enable or disable external services when viewing documents in Outlook on the web (for example, machine translation) by using Office Online Server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_internalspmysitehosturl: {
      type: 'Optional[String]',
      desc: 'The InternalSPMySiteHostURL specifies the My Site Host URL for internal users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_satisfactionenabled: {
      type: 'Optional[Boolean]',
      desc: 'The SatisfactionEnabled parameter specifies whether to enable or disable the satisfaction survey.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_instantmessagingtype: {
      type: "Optional[Enum['None', 'Ocs']]",
      desc: 'The InstantMessagingType parameter specifies the type of instant messaging provider in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_activesyncintegrationenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ActiveSyncIntegrationEnabled parameter specifies whether to enable or disable Exchange ActiveSync settings in Outlook on the web. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaulttheme: {
      type: 'Optional[String]',
      desc: "The DefaultTheme parameter specifies the default theme that's used in Outlook on the web when the user hasn't selected a theme. The default value is blank ($null).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_setphotoenabled: {
      type: 'Optional[Boolean]',
      desc: 'The SetPhotoEnabled parameter specifies whether users can add, change, and remove their sender photo in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_classicattachmentsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ClassicAttachmentsEnabled parameter specifies whether users can attach local files as regular email attachments in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowcopycontactstodeviceaddressbook: {
      type: 'Optional[Boolean]',
      desc: "The AllowCopyContactsToDeviceAddressBook parameter specifies whether users can copy the contents of their Contacts folder to a mobile device's native address book when using Outlook on the web for devices.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_useiso885915: {
      type: 'Optional[Boolean]',
      desc: 'The UseISO885915 parameter specifies whether to use the character set ISO8859-15 instead of ISO8859-1 in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_outboundcharset: {
      type: "Optional[Enum['AutoDetect', 'AlwaysUTF8', 'UserLanguageChoice']]",
      desc: "The OutboundCharset parameter specifies the character set that's used for outgoing messages in Outlook on the web.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_localeventsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The LocalEventsEnabled parameter specifies whether local events calendars are available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_reportjunkemailenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ReportJunkEmailEnabled parameter specifies whether users can report messages to Microsoft or unsubscribe from messages in Outlook on the web. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_forcewacviewingfirstonprivatecomputers: {
      type: 'Optional[Boolean]',
      desc: 'The ForceWacViewingFirstOnPrivateComputers parameter specifies whether private computers must first preview an Office file as a web page in Office Online Server (formerly known as Office Web Apps Server and Web Access Companion Server) before opening the file in the local application.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_recoverdeleteditemsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The RecoverDeletedItemsEnabled parameter specifies whether a user can use Outlook Web App to view, recover, or delete permanently items that have been deleted from the Deleted Items folder.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_instantmessagingenabled: {
      type: 'Optional[Boolean]',
      desc: 'The InstantMessagingEnabled parameter specifies whether instant messaging is available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_organizationenabled: {
      type: 'Optional[Boolean]',
      desc: "When the OrganizationEnabled parameter is set to $false, the Automatic Reply option doesn't include external and internal options, the address book doesn't show the organization hierarchy, and the Resources tab in Calendar forms is disabled.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_webpartsframeoptionstype: {
      type: "Optional[Enum['None', 'SameOrigin', 'Deny']]",
      desc: 'The WebPartsFrameOptionsType parameter specifies what sources can access web parts in IFRAME or FRAME elements in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_actionforunknownfileandmimetypes: {
      type: "Optional[Enum['Allow', 'ForceSave', 'Block']]",
      desc: "The ActionForUnknownFileAndMIMETypes parameter specifies how to handle file types that aren't specified in the Allow, Block, and Force Save lists for file types and MIME types",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_waceditingenabled: {
      type: 'Optional[Boolean]',
      desc: 'The WacEditingEnabled parameter specifies whether to enable or disable editing documents in Outlook on the web by using Office Online Server (formerly known as Office Web Apps Server and Web Access Companion Server). ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_publicfoldersenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PublicFoldersEnabled parameter specifies whether a user can browse or read items in public folders in Outlook Web App.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_forcesaveattachmentfilteringenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ForceSaveAttachmentFilteringEnabled parameter specifies whether files are filtered before they can be saved from Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logonanderrorlanguage: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: "The LogonAndErrorLanguage parameter specifies the language that used in Outlook on the web for forms-based authentication and for error messages when a user's current language setting can't be read. A valid value is a supported Microsoft Windows Language Code Identifier (LCID). For example, 1033 is US English.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_alladdresslistsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The AllAddressListsEnabled parameter specifies which address lists are available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_externalimageproxyenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ExternalImageProxyEnabled parameter specifies whether to load all external images through the Outlook external image proxy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_premiumclientenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PremiumClientEnabled parameter controls the availability of the full version of Outlook Web App.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_blockedmimetypes: {
      type: 'Optional[Array[String]]',
      desc: 'The BlockedMimeTypes parameter specifies MIME extensions in attachments that prevent the attachments from being saved locally or viewed from Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_umintegrationenabled: {
      type: 'Optional[Boolean]',
      desc: 'The UMIntegrationEnabled parameter specifies whether Unified Messaging (UM) integration is enabled in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_themeselectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ThemeSelectionEnabled parameter specifies whether users can change the theme in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isdefault: {
      type: 'Optional[Boolean]',
      desc: "The IsDefault switch specifies whether the Outlook on the web policy is the default policy that's used to configure the Outlook on the web settings for new mailboxes.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowedfiletypes: {
      type: 'Optional[Array[String]]',
      desc: 'The AllowedFileTypes parameter specifies the attachment file types (file extensions) that can be saved locally or viewed from Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_setphotourl: {
      type: 'Optional[String]',
      desc: "The SetPhotoURL parameter controls where users go to select their photo. Note that you can't specify a URL that contains one or more picture files, as there is no mechanism to copy a URL photo to the properties of the users' Exchange Online mailboxes.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rulesenabled: {
      type: 'Optional[Boolean]',
      desc: 'The RulesEnabled parameter specifies whether a user can view, create, or modify server-side rules in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_remindersandnotificationsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The RemindersAndNotificationsEnabled parameter specifies whether notifications and reminders are enabled in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_frecardsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The FreCardsEnabled parameter specifies whether the theme, signature, and phone cards are available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the unique name for the policy. The maximum length is 64 characters.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usegb18030: {
      type: 'Optional[Boolean]',
      desc: 'The UseGB18030 parameter specifies whether to use the GB18030 character set instead of GB2312 in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_additionalstorageprovidersavailable: {
      type: 'Optional[Boolean]',
      desc: 'The AdditionalStorageProvidersAvailable parameter specifies whether to allow additional storage providers (for example, Box, Dropbox, Facebook, Google Drive, Egnyte, personal OneDrive) attachments in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_interestingcalendarsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The InterestingCalendarsEnabled parameter specifies whether interesting calendars are available in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_owalightenabled: {
      type: 'Optional[Boolean]',
      desc: 'The OWALightEnabled parameter controls the availability of the light version of Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_printwithoutdownloadenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PrintWithoutDownloadEnabled specifies whether to allow printing of supported files without downloading the attachment in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_saveattachmentstocloudenabled: {
      type: 'Optional[Boolean]',
      desc: 'The SaveAttachmentsToCloudEnabled parameter specifies whether users can save regular email attachments to the cloud.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_skipcreateunifiedgroupcustomsharepointclassification: {
      type: 'Optional[Boolean]',
      desc: 'The SkipCreateUnifiedGroupCustomSharepointClassification parameter specifies whether to skip a custom SharePoint page during the creation of Office 365 Groups in Outlook web app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_referenceattachmentsenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ReferenceAttachmentsEnabled parameter specifies whether users can attach files from the cloud as linked attachments in Outlook on the web.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disablefacebook: {
      type: 'Optional[Boolean]',
      desc: 'The DisableFacebook switch specifies whether users can synchronize their Facebook contacts to their Contacts folder in Outlook on the web. By default, Facebook integration is enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_phoneticsupportenabled: {
      type: 'Optional[Boolean]',
      desc: 'The PhoneticSupportEnabled parameter specifies phonetically spelled entries in the address book. This parameter is available for use in Japan.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
