require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_exotransportrule',
  dscmeta_resource_friendly_name: 'EXOTransportRule',
  dscmeta_resource_name: 'MSFT_EXOTransportRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC EXOTransportRule resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_activationdate: {
      type: 'Optional[String]',
      desc: "The ActivationDate parameter specifies when the rule starts processing messages. The rule won't take any action on messages until the specified date/time.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addtorecipients: {
      type: 'Optional[Array[String]]',
      desc: 'The AddToRecipients parameter specifies an action that adds recipients to the To field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applyhtmldisclaimerfallbackaction: {
      type: "Optional[Enum['Wrap', 'Ignore', 'Reject']]",
      desc: "The ApplyHtmlDisclaimerFallbackAction parameter specifies what to do if the HTML disclaimer can't be added to a message.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifrecipientadattributecontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfRecipientADAttributeContainsWords parameter specifies an exception that looks for words in the Active Directory attributes of recipients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_recipientadattributematchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The RecipientADAttributeMatchesPatterns parameter specifies a condition that looks for text patterns in the Active Directory attributes of recipients by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_attachmentsizeover: {
      type: 'Optional[String]',
      desc: 'The AttachmentSizeOver parameter specifies a condition that looks for messages where any attachment is greater than the specified size.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifsenderadattributecontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSenderADAttributeContainsWords parameter specifies an exception that looks for words in Active Directory attributes of message senders.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_setscl: {
      type: 'Optional[String]',
      desc: 'The SetSCL parameter specifies an action that adds or modifies the SCL value of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_anyoftoheadermemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfToHeaderMemberOf parameter specifies a condition that looks for group members in the To field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsenttomemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSentToMemberOf parameter specifies an exception that looks for messages sent to members of groups. You can use any value that uniquely identifies the group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifanyofccheader: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfCcHeader parameter specifies an exception that looks for recipients in the Cc field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAttachmentMatchesPatterns parameter specifies an exception that looks for text patterns in the content of message attachments by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_recipientdomainis: {
      type: 'Optional[Array[String]]',
      desc: 'The RecipientDomainIs parameter specifies a condition that looks for recipients with email address in the specified domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_managerforevaluateduser: {
      type: "Optional[Enum['Recipient', 'Sender']]",
      desc: 'The ManagerForEvaluatedUser parameter specifies a condition that looks for users in the Manager attribute of senders or recipients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifheadermatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfHeaderMatchesPatterns parameter specifies an exception that looks for text patterns in a header field by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptiffromscope: {
      type: "Optional[Enum['InOrganization', 'NotInOrganization']]",
      desc: 'The ExceptIfFromScope parameter specifies an exception that looks for the location of message senders.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_adcomparisonattribute: {
      type: 'Optional[String]',
      desc: 'This parameter specifies a condition or part of a condition for the rule. The name of the corresponding exception parameter starts with ExceptIf.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentcontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAttachmentContainsWords parameter specifies an exception that looks for words in message attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifheadercontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfHeaderContainsWords parameter specifies an exception that looks for words in a header field.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_headermatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The HeaderMatchesPatterns parameter specifies a condition that looks for text patterns in a header field by using regular expressions. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentispasswordprotected: {
      type: 'Optional[Boolean]',
      desc: "The ExceptIfAttachmentIsPasswordProtected parameter specifies an exception that looks for password protected files in messages (because the contents of the file can't be inspected).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_deletemessage: {
      type: 'Optional[Boolean]',
      desc: 'The DeleteMessage parameter specifies an action that silently drops messages without an NDR.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hassenderoverride: {
      type: 'Optional[Boolean]',
      desc: 'The HasSenderOverride parameter specifies a condition that looks for messages where the sender chose to override a DLP policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifsubjectorbodymatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSubjectOrBodyMatchesPatterns parameter specifies an exception that looks for text patterns in the Subject field or body of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_exceptifhasclassification: {
      type: 'Optional[String]',
      desc: 'The ExceptIfHasClassification parameter specifies an exception that looks for messages with the specified message classification.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifanyofrecipientaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfRecipientAddressMatchesPatterns parameter specifies an exception that looks for text patterns in recipient email addresses by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifcontentcharactersetcontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfContentCharacterSetContainsWords parameter specifies an exception that looks for character set names in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for CertificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_blindcopyto: {
      type: 'Optional[Array[String]]',
      desc: 'The BlindCopyTo parameter specifies an action that adds recipients to the Bcc field of messages. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applyhtmldisclaimerlocation: {
      type: "Optional[Enum['Append', 'Prepend']]",
      desc: 'The ApplyHtmlDisclaimerLocation parameter specifies where to insert the HTML disclaimer text in the body of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifmessagetypematches: {
      type: "Optional[Enum['OOF', 'AutoForward', 'Encrypted', 'Calendaring', 'PermissionControlled', 'Voicemail', 'Signed', 'ApprovalRequest', 'ReadReceipt']]",
      desc: 'The ExceptIfMessageTypeMatches parameter specifies an exception that looks for messages of the specified type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_senderipranges: {
      type: 'Optional[Array[String]]',
      desc: 'The SenderIpRanges parameter specifies a condition that looks for senders whose IP addresses matches the specified value, or fall within the specified ranges.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifmessagecontainsdataclassifications: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfMessageContainsDataClassifications parameter specifies an exception that looks for sensitive information types in the body of messages, and in any attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_moderatemessagebyuser: {
      type: 'Optional[Array[String]]',
      desc: 'The ModerateMessageByUser parameter specifies an action that forwards messages for approval to the specified users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_hasnoclassification: {
      type: 'Optional[Boolean]',
      desc: 'The HasNoClassification parameter specifies a condition that looks for messages with or without any message classifications.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifsenderinrecipientlist: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_headercontainsmessageheader: {
      type: 'Optional[String]',
      desc: 'The HeaderContainsMessageHeader parameter specifies the name of header field in the message header when searching for the words specified by the HeaderContainsWords parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_removeheader: {
      type: 'Optional[String]',
      desc: 'The RemoveHeader parameter specifies an action that removes a header field from the message header.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_hasclassification: {
      type: 'Optional[String]',
      desc: 'The HasClassification parameter specifies a condition that looks for messages with the specified message classification.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_messagecontainsdataclassifications: {
      type: 'Optional[Array[String]]',
      desc: 'The MessageContainsDataClassifications parameter specifies a condition that looks for sensitive information types in the body of messages, and in any attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptiffrommemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfFromMemberOf parameter specifies an exception that looks for messages sent by group members.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rulesubtype: {
      type: "Optional[Enum['Dlp', 'None']]",
      desc: 'The RuleSubType parameter specifies the rule type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_senttoscope: {
      type: "Optional[Enum['InOrganization', 'NotInOrganization', 'ExternalPartner', 'ExternalNonPartner']]",
      desc: 'The SentToScope parameter specifies a condition that looks for the location of recipients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_anyoftoccheadermemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfToCcHeaderMemberOf parameter specifies a condition that looks for group members in the To and Cc fields of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_from: {
      type: 'Optional[Array[String]]',
      desc: 'The From parameter specifies a condition that looks for messages from specific senders. You can use any value that uniquely identifies the sender.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifanyofrecipientaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfRecipientAddressContainsWords parameter specifies an exception that looks for words in recipient email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifwithimportance: {
      type: "Optional[Enum['Low', 'Normal', 'High']]",
      desc: 'The ExceptIfWithImportance parameter specifies an exception that looks for messages with the specified importance level.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentcharactersetcontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ContentCharacterSetContainsWords parameter specifies a condition that looks for character set names in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_subjectcontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The SubjectContainsWords parameter specifies a condition that looks for words in the Subject field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_rejectmessageenhancedstatuscode: {
      type: 'Optional[String]',
      desc: "The RejectMessageEnhancedStatusCode parameter specifies the enhanced status code that's used when the rule rejects messages.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_senderadattributematchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The SenderADAttributeMatchesPatterns parameter specifies a condition that looks for text patterns in Active Directory attributes of message senders by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsenderadattributematchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSenderADAttributeMatchesPatterns parameter specifies an exception that looks for text patterns in Active Directory attributes of message senders by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_incidentreportcontent: {
      type: 'Optional[String]',
      desc: "The IncidentReportContent parameter specifies the message properties that are included in the incident report that's generated when a message violates a DLP policy. ",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_frommemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The FromMemberOf parameter specifies a condition that looks for messages sent by group members.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_attachmentcontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The AttachmentContainsWords parameter specifies a condition that looks for words in message attachments. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsclover: {
      type: 'Optional[String]',
      desc: 'The ExceptIfSCLOver parameter specifies an exception that looks for the SCL value of messages',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifbetweenmemberof1: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfBetweenMemberOf1 parameter specifies an exception that looks for messages that are sent between group members. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_generatenotification: {
      type: 'Optional[String]',
      desc: 'The GenerateNotification parameter specifies an action that sends a notification message to recipients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_notifysender: {
      type: "Optional[Enum['NotifyOnly', 'RejectMessage', 'RejectUnlessFalsePositiveOverride', 'RejectUnlessSilentOverride', 'RejectUnlessExplicitOverride']]",
      desc: 'The NotifySender parameter specifies an action that notifies the sender when messages violate DLP policies.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentnamematchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAttachmentNameMatchesPatterns parameter specifies an exception that looks for text patterns in the file name of message attachments by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsendermanagementrelationship: {
      type: "Optional[Enum['Manager', 'DirectReport']]",
      desc: 'The ExceptIfSenderManagementRelationship parameter specifies an exception that looks for the relationship between the sender and recipients in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_setauditseverity: {
      type: "Optional[Enum['DoNotAudit', 'Low', 'Medium', 'High']]",
      desc: "The SetAuditSeverity parameter specifies an action that sets the severity level of the incident report and the corresponding entry that's written to the message tracking log when messages violate DLP policies.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachmentpropertycontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The AttachmentPropertyContainsWords parameter specifies a condition that looks for words in the properties of attached Office documents.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifanyoftoheader: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfToHeader parameter specifies an exception that looks for recipients in the To field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_routemessageoutboundrequiretls: {
      type: 'Optional[Boolean]',
      desc: 'The RouteMessageOutboundRequireTls parameter specifies an action that uses Transport Layer Security (TLS) encryption to deliver messages outside your organization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_withimportance: {
      type: "Optional[Enum['Low', 'Normal', 'High']]",
      desc: 'The WithImportance parameter specifies a condition that looks for messages with the specified importance level.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ruleerroraction: {
      type: "Optional[Enum['Ignore', 'Defer']]",
      desc: "The RuleErrorAction parameter specifies what to do if rule processing can't be completed on messages.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fromscope: {
      type: "Optional[Enum['InOrganization', 'NotInOrganization']]",
      desc: 'The FromScope parameter specifies a condition that looks for the location of message senders.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachmentnamematchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The AttachmentNameMatchesPatterns parameter specifies a condition that looks for text patterns in the file name of message attachments by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sentto: {
      type: 'Optional[Array[String]]',
      desc: 'The SentTo parameter specifies a condition that looks for recipients in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptiffromaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: "The ExceptIfFromAddressMatchesPatterns parameter specifies an exception that looks for text patterns in the sender's email address by using regular expressions.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'The Enabled parameter specifies whether the new rule is created as enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentsizeover: {
      type: 'Optional[String]',
      desc: 'The ExceptIfAttachmentSizeOver parameter specifies an exception that looks for messages where any attachment is greater than the specified size.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifmanagerforevaluateduser: {
      type: 'Optional[String]',
      desc: 'The ExceptIfManagerForEvaluatedUser parameter specifies an exception that looks for users in the Manager attribute of senders or recipients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_removeomev2: {
      type: 'Optional[Boolean]',
      desc: 'The RemoveOMEv2 parameter specifies an action that removes Office 365 Message Encryption from messages and their attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptiffromaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: "The ExceptIfFromAddressContainsWords parameter specifies an exception that looks for words in the sender's email address.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_attachmenthasexecutablecontent: {
      type: 'Optional[Boolean]',
      desc: 'The AttachmentHasExecutableContent parameter specifies a condition that looks for executable content in message attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_routemessageoutboundconnector: {
      type: 'Optional[String]',
      desc: 'The RouteMessageOutboundConnector parameter specifies an action that routes messages through the specified Outbound connector in Office 365.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_subjectmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The SubjectMatchesPatterns parameter specifies a condition that looks for text patterns in the Subject field of messages by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifrecipientdomainis: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfRecipientDomainIs parameter specifies an exception that looks for recipients with email address in the specified domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsenderdomainis: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSenderDomainIs parameter specifies an exception that looks for senders with email address in the specified domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sendermanagementrelationship: {
      type: "Optional[Enum['Manager', 'DirectReport']]",
      desc: 'The SenderManagementRelationship parameter specifies a condition that looks for the relationship between the sender and recipients in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifbetweenmemberof2: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfBetweenMemberOf2 parameter specifies an exception that looks for messages that are sent between group members.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_redirectmessageto: {
      type: 'Optional[Array[String]]',
      desc: 'The RedirectMessageTo parameter specifies a rule action that redirects messages to the specified recipients.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applyome: {
      type: 'Optional[Boolean]',
      desc: 'The ApplyOME parameter specifies an action that encrypts messages and their attachments by using Office 365 Message Encryption.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_addmanagerasrecipienttype: {
      type: "Optional[Enum['To', 'Cc', 'Bcc', 'Redirect']]",
      desc: "The AddManagerAsRecipientType parameter specifies an action that delivers or redirects messages to the user that's defined in the sender's Manager attribute.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifmessagesizeover: {
      type: 'Optional[String]',
      desc: 'The ExceptIfMessageSizeOver parameter specifies an exception that looks for messages larger than the specified size. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recipientinsenderlist: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_messagesizeover: {
      type: 'Optional[String]',
      desc: 'The MessageSizeOver parameter specifies a condition that looks for messages larger than the specified size. The size includes the message and all attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifrecipientinsenderlist: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmenthasexecutablecontent: {
      type: 'Optional[Boolean]',
      desc: 'The ExceptIfAttachmentHasExecutableContent parameter specifies an exception that looks for executable content in message attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentisunsupported: {
      type: 'Optional[Boolean]',
      desc: 'The ExceptIfAttachmentIsUnsupported parameter specifies an exception that looks for unsupported file types in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_removeome: {
      type: 'Optional[Boolean]',
      desc: 'The RemoveOME parameter specifies an action that removes the previous version of Office 365 Message Encryption from messages and their attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rejectmessagereasontext: {
      type: 'Optional[String]',
      desc: "The RejectMessageReasonText parameter specifies the explanation text that's used when the rule rejects messages.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recipientaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The RecipientAddressContainsWords parameter specifies a condition that looks for words in recipient email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_generateincidentreport: {
      type: 'Optional[String]',
      desc: "The GenerateIncidentReport parameter specifies where to send the incident report that's defined by the IncidentReportContent parameter.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fromaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: "The FromAddressContainsWords parameter specifies a condition that looks for words in the sender's email address. ",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_anyofrecipientaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfRecipientAddressMatchesPatterns parameter specifies a condition that looks for text patterns in recipient email addresses by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applyhtmldisclaimertext: {
      type: 'Optional[String]',
      desc: 'The ApplyHtmlDisclaimerText parameter specifies an action that adds the disclaimer text to messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recipientaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The RecipientAddressMatchesPatterns parameter specifies a condition that looks for text patterns in recipient email addresses by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsubjectcontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSubjectContainsWords parameter specifies an exception that looks for words in the Subject field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptiffrom: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfFrom parameter specifies an exception that looks for messages from specific senders.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_anyoftoccheader: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfToCcHeader parameter specifies a condition that looks for recipients in the To or Cc fields of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsenttoscope: {
      type: "Optional[Enum['InOrganization', 'NotInOrganization', 'ExternalPartner', 'ExternalNonPartner']]",
      desc: 'The ExceptIfSentToScope parameter specifies an exception that looks for the location of a recipient. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifanyoftoccheadermemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfToCcHeaderMemberOf parameter specifies an exception that looks for group members in the To and Cc fields of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_moderatemessagebymanager: {
      type: 'Optional[Boolean]',
      desc: "The ModerateMessageByManager parameter specifies an action that forwards messages for approval to the user that's specified in the sender's Manager attribute.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_adcomparisonoperator: {
      type: "Optional[Enum['Equal', 'NotEqual']]",
      desc: 'This parameter specifies a condition or part of a condition for the rule. The name of the corresponding exception parameter starts with ExceptIf.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_betweenmemberof2: {
      type: 'Optional[Array[String]]',
      desc: 'The BetweenMemberOf2 parameter specifies a condition that looks for messages that are sent between group members.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_setheadername: {
      type: 'Optional[String]',
      desc: 'The SetHeaderName parameter specifies an action that adds or modifies a header field in the message header.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachmentprocessinglimitexceeded: {
      type: 'Optional[Boolean]',
      desc: "The AttachmentProcessingLimitExceeded parameter specifies a condition that looks for messages where attachment scanning didn't complete.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifanyofccheadermemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfCcHeaderMemberOf parameter specifies an exception that looks for group members in the Cc field of messages. You can use any value that uniquely identifies the group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsubjectmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSubjectMatchesPatterns parameter specifies an exception that looks for text patterns in the Subject field of messages by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the display name of the transport rule to be created. The maximum length is 64 characters.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifrecipientaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfRecipientAddressContainsWords parameter specifies an exception that looks for words in recipient email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_headermatchesmessageheader: {
      type: 'Optional[String]',
      desc: 'The HeaderMatchesMessageHeader parameter specifies the name of header field in the message header when searching for the text patterns specified by the HeaderMatchesPatterns parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_anyofrecipientaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfRecipientAddressContainsWords parameter specifies a condition that looks for words in recipient email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_headercontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The HeaderContainsWords parameter specifies a condition that looks for words in a header field.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_comments: {
      type: 'Optional[String]',
      desc: "The Comments parameter specifies optional descriptive text for the rule. The length of the comment can't exceed 1024 characters.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_senttomemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The SentToMemberOf parameter specifies a condition that looks for messages sent to members of distribution groups, dynamic distribution groups, or mail-enabled security groups.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifadcomparisonattribute: {
      type: 'Optional[String]',
      desc: 'The ExceptIfADComparisonAttribute parameter specifies an exception that compares an Active Directory attribute between the sender and all recipients of the message.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifsentto: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSentTo parameter specifies an exception that looks for recipients in messages. You can use any value that uniquely identifies the recipient.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifadcomparisonoperator: {
      type: "Optional[Enum['Equal', 'NotEqual']]",
      desc: 'The ExceptIfADComparisonOperator parameter specifies the comparison operator for the ExceptIfADComparisonAttribute parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifanyoftoheadermemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfToHeaderMemberOf parameter specifies an exception that looks for group members in the To field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_mode: {
      type: "Optional[Enum['Audit', 'AuditAndNotify', 'Enforce']]",
      desc: 'The Mode parameter specifies how the rule operates.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifanyoftoccheader: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAnyOfToCcHeader parameter specifies an exception that looks for recipients in the To or Cc fields of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_subjectorbodymatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The SubjectOrBodyMatchesPatterns parameter specifies a condition that looks for text patterns in the Subject field or body of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentextensionmatcheswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAttachmentExtensionMatchesWords parameter specifies an exception that looks for words in the file name extensions of message attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_senderdomainis: {
      type: 'Optional[Array[String]]',
      desc: 'The SenderDomainIs parameter specifies a condition that looks for senders with email address in the specified domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifrecipientaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfRecipientAddressMatchesPatterns parameter specifies an exception that looks for text patterns in recipient email addresses by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifhasnoclassification: {
      type: 'Optional[Boolean]',
      desc: 'The ExceptIfHasNoClassification parameter specifies an exception that looks for messages with or without any message classifications.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifsenderipranges: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSenderIpRanges parameter specifies an exception that looks for senders whose IP addresses matches the specified value, or fall within the specified ranges.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifrecipientadattributematchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfRecipientADAttributeMatchesPatterns parameter specifies an exception that looks for text patterns in the Active Directory attributes of recipients by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_incidentreportoriginalmail: {
      type: 'Optional[String]',
      desc: 'The IncidentReportOriginalMail parameter specifies whether to include the original message with the incident report. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recipientadattributecontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The RecipientADAttributeContainsWords parameter specifies a condition that looks for words in the Active Directory attributes of recipients. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_attachmentisunsupported: {
      type: 'Optional[Boolean]',
      desc: 'The AttachmentIsUnsupported parameter specifies a condition that looks for unsupported file types in messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_expirydate: {
      type: 'Optional[String]',
      desc: "The ExpiryDate parameter specifies when this rule will stop processing messages. The rule won't take any action on messages after the specified date/time.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachmentextensionmatcheswords: {
      type: 'Optional[Array[String]]',
      desc: 'The AttachmentExtensionMatchesWords parameter specifies a condition that looks for words in the file name extensions of message attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsubjectorbodycontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSubjectOrBodyContainsWords parameter specifies an exception that looks for words in the Subject field or body of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifmanageraddresses: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfManagerAddresses parameter specifies the users (managers) for the ExceptIfManagerForEvaluatedUser parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_senderinrecipientlist: {
      type: 'Optional[String]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachmentmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The AttachmentMatchesPatterns parameter specifies a condition that looks for text patterns in the content of message attachments by using regular expressions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_dlppolicy: {
      type: 'Optional[String]',
      desc: "The DlpPolicy parameter specifies the data loss prevention (DLP) policy that's associated with the rule.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_manageraddresses: {
      type: 'Optional[Array[String]]',
      desc: 'The ManagerAddresses parameter specifies the users (managers) for the ExceptIfManagerForEvaluatedUser parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_senderaddresslocation: {
      type: "Optional[Enum['Header', 'Envelope', 'HeaderOrEnvelope']]",
      desc: 'The SenderAddressLocation parameter specifies where to look for sender addresses in conditions and exceptions that examine sender email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_copyto: {
      type: 'Optional[Array[String]]',
      desc: 'The CopyTo parameter specifies an action that adds recipients to the Cc field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_subjectorbodycontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The SubjectOrBodyContainsWords parameter specifies a condition that looks for words in the Subject field or body of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_applyclassification: {
      type: 'Optional[String]',
      desc: 'The ApplyClassification parameter specifies an action that applies a message classification to messages. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_setheadervalue: {
      type: 'Optional[String]',
      desc: 'The SetHeaderValue parameter specifies an action that adds or modifies a header field in the message header.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_priority: {
      type: 'Optional[String]',
      desc: 'The Priority parameter specifies a priority value for the rule that determines the order of rule processing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachmentispasswordprotected: {
      type: 'Optional[Boolean]',
      desc: "The AttachmentIsPasswordProtected parameter specifies a condition that looks for password protected files in messages (because the contents of the file can't be inspected).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_betweenmemberof1: {
      type: 'Optional[Array[String]]',
      desc: 'The BetweenMemberOf1 parameter specifies a condition that looks for messages that are sent between group members.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifmessagecontainsalldataclassifications: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_anyofccheader: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfCcHeader parameter specifies a condition that looks for recipients in the Cc field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if the Transport Rule should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentprocessinglimitexceeded: {
      type: 'Optional[Boolean]',
      desc: "The ExceptIfAttachmentProcessingLimitExceeded parameter specifies an exception that looks for messages where attachment scanning didn't complete.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_fromaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: "The FromAddressMatchesPatterns parameter specifies a condition that looks for text patterns in the sender's email address by using regular expressions.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifheadermatchesmessageheader: {
      type: 'Optional[String]',
      desc: 'The ExceptIfHeaderMatchesMessageHeader parameter specifies the name of header field in the message header when searching for the text patterns specified by the ExceptIfHeaderMatchesPatterns parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_anyofccheadermemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfCcHeaderMemberOf parameter specifies a condition that looks for group members in the Cc field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_senderadattributecontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The SenderADAttributeContainsWords parameter specifies a condition that looks for words in Active Directory attributes of message senders.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_anyoftoheader: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfToHeader parameter specifies a condition that looks for recipients in the To field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifhassenderoverride: {
      type: 'Optional[Boolean]',
      desc: 'The ExceptIfHasSenderOverride parameter specifies an exception that looks for messages where the sender chose to override a DLP policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sclover: {
      type: 'Optional[String]',
      desc: 'The SCLOver parameter specifies a condition that looks for the SCL value of messages',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_prependsubject: {
      type: 'Optional[String]',
      desc: 'The PrependSubject parameter specifies an action that adds text to add to the beginning of the Subject field of messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applyrightsprotectiontemplate: {
      type: 'Optional[String]',
      desc: 'The ApplyRightsProtectionTemplate parameter specifies an action that applies rights management service (RMS) templates to messages. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_messagetypematches: {
      type: "Optional[Enum['OOF', 'AutoForward', 'Encrypted', 'Calendaring', 'PermissionControlled', 'Voicemail', 'Signed', 'ApprovalRequest', 'ReadReceipt']]",
      desc: 'The MessageTypeMatches parameter specifies a condition that looks for messages of the specified type.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifattachmentpropertycontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfAttachmentPropertyContainsWords parameter specifies an exception that looks for words in the properties of attached Office documents. ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_stopruleprocessing: {
      type: 'Optional[Boolean]',
      desc: 'The StopRuleProcessing parameter specifies an action that stops processing more rules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_messagecontainsalldataclassifications: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifheadercontainsmessageheader: {
      type: 'Optional[String]',
      desc: 'The ExceptIfHeaderContainsMessageHeader parameter specifies the name of header field in the message header when searching for the words specified by the ExceptIfHeaderContainsWords parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
