require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedevicecompliancepolicyandroid',
  dscmeta_resource_friendly_name: 'IntuneDeviceCompliancePolicyAndroid',
  dscmeta_resource_name: 'MSFT_IntuneDeviceCompliancePolicyAndroid',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceCompliancePolicyAndroid resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequireverifyapps: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireVerifyApps of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_securitydisableusbdebugging: {
      type: 'Optional[Boolean]',
      desc: 'SecurityDisableUsbDebugging of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'DeviceThreatProtectionEnabled of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequiresafetynetattestationcertifieddevice: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireSafetyNetAttestationCertifiedDevice of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Display name of the Android device compliance policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_restrictedapps: {
      type: 'Optional[String]',
      desc: 'RestrictedApps of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storagerequireencryption: {
      type: 'Optional[Boolean]',
      desc: 'StorageRequireEncryption of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requiredpasswordcomplexity: {
      type: "Optional[Enum['none', 'low', 'medium', 'high']]",
      desc: 'RequiredPasswordComplexity of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_osmaximumversion: {
      type: 'Optional[String]',
      desc: 'OsMaximumVersion of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequiresafetynetattestationbasicintegrity: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireSafetyNetAttestationBasicIntegrity of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityblockjailbrokendevices: {
      type: 'Optional[Boolean]',
      desc: 'SecurityBlockJailbrokenDevices of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_minandroidsecuritypatchlevel: {
      type: 'Optional[String]',
      desc: 'MinAndroidSecurityPatchLevel of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_securityrequireuptodatesecurityproviders: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireUpToDateSecurityProviders of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_devicethreatprotectionrequiredsecuritylevel: {
      type: "Optional[Enum['unavailable', 'secured', 'low', 'medium', 'high', 'notSet']]",
      desc: 'DeviceThreatProtectionRequiredSecurityLevel of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rolescopetagids: {
      type: 'Optional[String]',
      desc: 'RoleScopeTagIds of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityblockdeviceadministratormanageddevices: {
      type: 'Optional[Boolean]',
      desc: 'SecurityBlockDeviceAdministratorManagedDevices of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordexpirationdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordExpirationDays of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_advancedthreatprotectionrequiredsecuritylevel: {
      type: "Optional[Enum['unavailable', 'secured', 'low', 'medium', 'high', 'notSet']]",
      desc: 'AdvancedThreatProtectionRequiredSecurityLevel of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequiregoogleplayservices: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireGooglePlayServices of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_conditionstatementid: {
      type: 'Optional[String]',
      desc: 'ConditionStatementId of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordrequired: {
      type: 'Optional[Boolean]',
      desc: 'PasswordRequired of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminimumlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinimumLength of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordsigninfailurecountbeforefactoryreset: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordSignInFailureCountBeforeFactoryReset of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequirecompanyportalappintegrity: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireCompanyPortalAppIntegrity of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_securitypreventinstallappsfromunknownsources: {
      type: 'Optional[Boolean]',
      desc: 'SecurityPreventInstallAppsFromUnknownSources of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_osminimumversion: {
      type: 'Optional[String]',
      desc: 'OsMinimumVersion of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordpreviouspasswordblockcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordPreviousPasswordBlockCount of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordrequiredtype: {
      type: "Optional[Enum['deviceDefault', 'alphabetic', 'alphanumeric', 'alphanumericWithSymbols', 'lowSecurityBiometric', 'numeric', 'numericComplex', 'any']]",
      desc: 'PasswordRequiredType of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordminutesofinactivitybeforelock: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinutesOfInactivityBeforeLock of the Android device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
