require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedevicecompliancepolicyandroiddeviceowner',
  dscmeta_resource_friendly_name: 'IntuneDeviceCompliancePolicyAndroidDeviceOwner',
  dscmeta_resource_name: 'MSFT_IntuneDeviceCompliancePolicyAndroidDeviceOwner',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceCompliancePolicyAndroidDeviceOwner resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_passwordexpirationdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordExpirationDays of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordminimumlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinimumLength of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Display name of the Android Device Owner device compliance policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequiresafetynetattestationbasicintegrity: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireSafetyNetAttestationBasicIntegrity of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordrequired: {
      type: 'Optional[Boolean]',
      desc: 'PasswordRequired of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_rolescopetagids: {
      type: 'Optional[Array[String]]',
      desc: 'List of Scope Tags for this Entity instance. Inherited from deviceConfiguration',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_osmaximumversion: {
      type: 'Optional[String]',
      desc: 'osMaximumVersion of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequiresafetynetattestationcertifieddevice: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireSafetyNetAttestationCertifiedDevice of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_advancedthreatprotectionrequiredsecuritylevel: {
      type: 'Optional[String]',
      desc: 'AdvancedThreatProtectionRequiredSecurityLevel of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordrequiredtype: {
      type: "Optional[Enum['deviceDefault', 'alphabetic', 'alphanumeric', 'alphanumericWithSymbols', 'lowSecurityBiometric', 'numeric', 'numericComplex', 'any']]",
      desc: 'PasswordRequiredType of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionrequiredsecuritylevel: {
      type: 'Optional[String]',
      desc: 'DeviceThreatProtectionRequiredSecurityLevel of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_securityrequireintuneappintegrity: {
      type: 'Optional[Boolean]',
      desc: 'SecurityRequireIntuneAppIntegrity of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminutesofinactivitybeforelock: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinutesOfInactivityBeforeLock of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordpreviouspasswordcounttoblock: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordPreviousPasswordCountToBlock of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_osminimumversion: {
      type: 'Optional[String]',
      desc: 'osMinimumVersion of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'DeviceThreatProtectionEnabled of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storagerequireencryption: {
      type: 'Optional[Boolean]',
      desc: 'StorageRequireEncryption of the Android Device Owner device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
