require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedevicecompliancepolicyios',
  dscmeta_resource_friendly_name: 'IntuneDeviceCompliancePolicyiOs',
  dscmeta_resource_name: 'MSFT_IntuneDeviceCompliancePolicyiOs',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceCompliancePolicyiOs resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_passcodeblocksimple: {
      type: 'Optional[Boolean]',
      desc: 'PasscodeBlockSimple of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Display name of the iOS device compliance policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passcodeminimumcharactersetcount: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'PasscodeMinimumCharacterSetCount of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_passcodeexpirationdays: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'PasscodeExpirationDays of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_osmaximumversion: {
      type: 'Optional[String]',
      desc: 'OsMaximumVersion of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passcoderequiredtype: {
      type: 'Optional[String]',
      desc: 'PasscodeRequiredType of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passcodeminimumlength: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'PasscodeMinimumLength of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionrequiredsecuritylevel: {
      type: 'Optional[String]',
      desc: 'DeviceThreatProtectionRequiredSecurityLevel of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passcodeminutesofinactivitybeforelock: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'PasscodeMinutesOfInactivityBeforeLock of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_passcodepreviouspasscodeblockcount: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'PasscodePreviousPasscodeBlockCount of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_securityblockjailbrokendevices: {
      type: 'Optional[Boolean]',
      desc: 'SecurityBlockJailbrokenDevices of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passcoderequired: {
      type: 'Optional[Boolean]',
      desc: 'PasscodeRequired of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_osminimumversion: {
      type: 'Optional[String]',
      desc: 'OsMinimumVersion of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'DeviceThreatProtectionEnabled of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_managedemailprofilerequired: {
      type: 'Optional[Boolean]',
      desc: 'ManagedEmailProfileRequired of the iOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
