require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedevicecompliancepolicymacos',
  dscmeta_resource_friendly_name: 'IntuneDeviceCompliancePolicyMacOS',
  dscmeta_resource_name: 'MSFT_IntuneDeviceCompliancePolicyMacOS',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceCompliancePolicyMacOS resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_passwordexpirationdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordExpirationDays of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordminimumlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinimumLength of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_systemintegrityprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'SystemIntegrityProtectionEnabled of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Display name of the MacOS device compliance policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firewallblockallincoming: {
      type: 'Optional[Boolean]',
      desc: 'FirewallBlockAllIncoming of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordrequired: {
      type: 'Optional[Boolean]',
      desc: 'PasswordRequired of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storagerequireencryption: {
      type: 'Optional[Boolean]',
      desc: 'StorageRequireEncryption of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminimumcharactersetcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinimumCharacterSetCount of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionrequiredsecuritylevel: {
      type: "Optional[Enum['Unavailable', 'Secured', 'Low', 'Medium', 'High', 'NotSet']]",
      desc: 'DeviceThreatProtectionRequiredSecurityLevel of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_osminimumversion: {
      type: 'Optional[String]',
      desc: 'OsMinimumVersion of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordpreviouspasswordblockcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordPreviousPasswordBlockCount of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordrequiredtype: {
      type: "Optional[Enum['DeviceDefault', 'Alphanumeric', 'Numeric']]",
      desc: 'PasswordRequiredType of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firewallenablestealthmode: {
      type: 'Optional[Boolean]',
      desc: 'FirewallEnableStealthMode of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordblocksimple: {
      type: 'Optional[Boolean]',
      desc: 'PasswordBlockSimple of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminutesofinactivitybeforelock: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinutesOfInactivityBeforeLock of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_osmaximumversion: {
      type: 'Optional[String]',
      desc: 'OsMaximumVersion of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firewallenabled: {
      type: 'Optional[Boolean]',
      desc: 'FirewallEnabled of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'DeviceThreatProtectionEnabled of the MacOS device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
