require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedevicecompliancepolicywindows10',
  dscmeta_resource_friendly_name: 'IntuneDeviceCompliancePolicyWindows10',
  dscmeta_resource_name: 'MSFT_IntuneDeviceCompliancePolicyWindows10',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceCompliancePolicyWindows10 resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_antivirusrequired: {
      type: 'Optional[Boolean]',
      desc: 'AntivirusRequired of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'DeviceThreatProtectionEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requirehealthydevicereport: {
      type: 'Optional[Boolean]',
      desc: 'RequireHealthyDeviceReport of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Display name of the Windows 10 device compliance policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_storagerequireencryption: {
      type: 'Optional[Boolean]',
      desc: 'StorageRequireEncryption of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_activefirewallrequired: {
      type: 'Optional[Boolean]',
      desc: 'ActiveFirewallRequired of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mobileosminimumversion: {
      type: 'Optional[String]',
      desc: 'MobileOsMinimumVersion of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_osmaximumversion: {
      type: 'Optional[String]',
      desc: 'OsMaximumVersion of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_validoperatingsystembuildranges: {
      type: 'Optional[Array[String]]',
      desc: 'ValidOperatingSystemBuildRanges of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_devicecompliancepolicyscript: {
      type: 'Optional[String]',
      desc: 'DeviceCompliancePolicyScript of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tpmrequired: {
      type: 'Optional[Boolean]',
      desc: 'TPMRequired of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_securebootenabled: {
      type: 'Optional[Boolean]',
      desc: 'SecureBootEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_antispywarerequired: {
      type: 'Optional[Boolean]',
      desc: 'AntiSpywareRequired of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderversion: {
      type: 'Optional[String]',
      desc: 'DefenderVersion of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_codeintegrityenabled: {
      type: 'Optional[Boolean]',
      desc: 'CodeIntegrityEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_signatureoutofdate: {
      type: 'Optional[Boolean]',
      desc: 'SignatureOutOfDate of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_passwordrequiredtype: {
      type: "Optional[Enum['DeviceDefault', 'Alphanumeric', 'Numeric']]",
      desc: 'PasswordRequiredType of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_devicethreatprotectionrequiredsecuritylevel: {
      type: "Optional[Enum['Unavailable', 'Secured', 'Low', 'Medium', 'High', 'NotSet']]",
      desc: 'DeviceThreatProtectionRequiredSecurityLevel of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_rtpenabled: {
      type: 'Optional[Boolean]',
      desc: 'RTPEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_mobileosmaximumversion: {
      type: 'Optional[String]',
      desc: 'MobileOsMaximumVersion of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordexpirationdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordExpirationDays of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_configurationmanagercompliancerequired: {
      type: 'Optional[Boolean]',
      desc: 'ConfigurationManagerComplianceRequired of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordrequired: {
      type: 'Optional[Boolean]',
      desc: 'PasswordRequired of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminimumlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinimumLength of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_defenderenabled: {
      type: 'Optional[Boolean]',
      desc: 'DefenderEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_earlylaunchantimalwaredriverenabled: {
      type: 'Optional[Boolean]',
      desc: 'EarlyLaunchAntiMalwareDriverEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bitlockerenabled: {
      type: 'Optional[Boolean]',
      desc: 'BitLockerEnabled of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_osminimumversion: {
      type: 'Optional[String]',
      desc: 'OsMinimumVersion of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordpreviouspasswordblockcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordPreviousPasswordBlockCount of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordblocksimple: {
      type: 'Optional[Boolean]',
      desc: 'PasswordBlockSimple of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordrequiredtounlockfromidle: {
      type: 'Optional[Boolean]',
      desc: 'PasswordRequiredToUnlockFromIdle of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminimumcharactersetcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinimumCharacterSetCount of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordminutesofinactivitybeforelock: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'PasswordMinutesOfInactivityBeforeLock of the Windows 10 device compliance policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
