require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedeviceconfigurationpolicyandroidworkprofile',
  dscmeta_resource_friendly_name: 'IntuneDeviceConfigurationPolicyAndroidWorkProfile',
  dscmeta_resource_name: 'MSFT_IntuneDeviceConfigurationPolicyAndroidWorkProfile',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceConfigurationPolicyAndroidWorkProfile resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_workprofilepasswordblocktrustagents: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block Smart Lock and other trust agents for work profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofileblocknotificationswhiledevicelocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block notifications while device locked',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the device general configuration policy for Android WorkProfile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofilerequirepassword: {
      type: 'Optional[Boolean]',
      desc: 'Password is required or not for work profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminnumericcharacters: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum count of numeric characters required in work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Display name of the device general configuration policy for Android WorkProfile.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminlowercasecharacters: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum count of lower-case characters required in work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordblockfingerprintunlock: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block fingerprint unlock',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordblocktrustagents: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block Smart Lock and other trust agents.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordrequiredtype: {
      type: "Optional[Enum['deviceDefault', 'lowSecurityBiometric', 'required', 'atLeastNumeric', 'numericComplex', 'atLeastAlphabetic', 'atLeastAlphanumeric', 'alphanumericWithSymbols']]",
      desc: 'Type of password that is required',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordsigninfailurecountbeforefactoryreset: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of sign in failures allowed before work profile is removed and all corporate data deleted',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofiledatasharingtype: {
      type: "Optional[Enum['deviceDefault', 'preventAny', 'allowPersonalToWork', 'noRestrictions']]",
      desc: 'Type of data sharing that is allowed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordblockfingerprintunlock: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block fingerprint unlock for work profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workprofileblockcrossprofilecopypaste: {
      type: 'Optional[Boolean]',
      desc: 'Boolean that indicates if the setting disallow cross profile copy paste is enabled',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Active Directory tenant used for authentication. Format contoso.onmicrosoft.com',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminutesofinactivitybeforescreentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minutes of inactivity before the screen times out',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_workprofileblockcrossprofilecontactssearch: {
      type: 'Optional[Boolean]',
      desc: 'Block work profile contacts availability in personal profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_securityrequireverifyapps: {
      type: 'Optional[Boolean]',
      desc: 'Require the Android Verify apps feature is turned on',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordrequiredtype: {
      type: "Optional[Enum['deviceDefault', 'lowSecurityBiometric', 'required', 'atLeastNumeric', 'numericComplex', 'atLeastAlphabetic', 'atLeastAlphanumeric', 'alphanumericWithSymbols']]",
      desc: 'Type of work profile password that is required',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordexpirationdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of days before the password expires',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminsymbolcharacters: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum count of symbols required in work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminuppercasecharacters: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum count of upper-case characters required in work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the site collection exists, absent ensures it is removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_workprofileblockscreencapture: {
      type: 'Optional[Boolean]',
      desc: 'Block screen capture in work profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_workprofilepasswordminimumlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum length of work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordpreviouspasswordblockcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of previous work profile passwords to block',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordminimumlength: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum length of passwords',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_passwordsigninfailurecountbeforefactoryreset: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of sign in failures allowed before factory reset',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofileblockaddingaccounts: {
      type: 'Optional[Boolean]',
      desc: 'Block users from adding/removing accounts in work profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminutesofinactivitybeforescreentimeout: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minutes of inactivity before the screen times out',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminlettercharacters: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum count of letter characters required in work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofileblockcrossprofilecallerid: {
      type: 'Optional[Boolean]',
      desc: 'Block display work profile caller ID in personal profile',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workprofileblockcamera: {
      type: 'Optional[Boolean]',
      desc: 'Block work profile camera',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordpreviouspasswordblockcount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of previous passwords to block',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofilebluetoothenablecontactsharing: {
      type: 'Optional[Boolean]',
      desc: 'Allow bluetooth devices to access enterprise contacts',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordexpirationdays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Number of days before the work profile password expires',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofilepasswordminnonlettercharacters: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Minimum count of non-letter characters required in work profile password',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_workprofiledefaultapppermissionpolicy: {
      type: "Optional[Enum['deviceDefault', 'prompt', 'autoGrant', 'autoDeny']]",
      desc: 'Type of password that is required',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
