require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_intunedeviceconfigurationpolicywindows10',
  dscmeta_resource_friendly_name: 'IntuneDeviceConfigurationPolicyWindows10',
  dscmeta_resource_name: 'MSFT_IntuneDeviceConfigurationPolicyWindows10',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC IntuneDeviceConfigurationPolicyWindows10 resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_enterprisecloudprintresourceidentifier: {
      type: 'Optional[String]',
      desc: 'OAuth resource URI for print service as configured in the Azure portal.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_bluetoothblocked: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using bluetooth.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgedisablefirstrunpage: {
      type: 'Optional[Boolean]',
      desc: 'Block the Microsoft web page that opens on the first use of Microsoft Edge. This policy allows enterprises, like those enrolled in zero emissions configurations, to block this page.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_experienceblockerrordialogwhennosim: {
      type: 'Optional[Boolean]',
      desc: 'NIndicates whether or not to allow the error dialog from displaying if no SIM card is detected.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscanmaxcpu: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Max CPU usage percentage during scan. Valid values 0 to 100',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_cortanablocked: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using Cortana.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfoldermusic: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Music folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defenderscannetworkfiles: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan files opened from a network folder.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordrequired: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require the user to have a password.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfoldervideos: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Videos folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wirelessdisplayblockuserinputfromreceiver: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to allow user input from wireless display receiver.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderprocessestoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Processes to exclude from scans and real time protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfolderpersonalfolder: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the PersonalFolder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblocktailoredexperiences: {
      type: 'Optional[Boolean]',
      desc: 'Block personalized content in Windows spotlight based on users device usage.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_appsallowtrustedappssideloading: {
      type: 'Optional[String]',
      desc: 'Indicates whether apps from AppX packages signed with a trusted certificate can be side loaded. Possible values are: notConfigured, blocked, allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_smartscreenenableappinstallcontrol: {
      type: 'Optional[Boolean]',
      desc: 'This property will be deprecated in July 2019 and will be replaced by property SmartScreenAppInstallControl. Allows IT Admins to control whether users are allowed to install apps from places other than the Store.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockchangesystemtime: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from changing date and time settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storagerestrictappdatatosystemvolume: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether application data is restricted to the system drive.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_lockscreenblockactioncenternotifications: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block action center notifications over lock screen.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhiderecentjumplists: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides recent jump lists from appearing on the start menu/taskbar and disables the corresponding toggle in the Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblocksystempage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to System in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_devicemanagementblockmanualunenroll: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from doing manual un-enrollment from device management.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordpreviouspasswordblockcount: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The number of previous passwords to prevent reuse of. Valid values 0 to 50',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_edgeclearbrowsingdataonexit: {
      type: 'Optional[Boolean]',
      desc: 'Clear browsing data on exiting Microsoft Edge.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordblocksimple: {
      type: 'Optional[Boolean]',
      desc: "Specify whether PINs or passwords such as '1111' or '1234' are allowed. For Windows 10 desktops, it also controls the use of picture passwords.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhidesignout: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides sign out from appearing in the user tile in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defendersystemscanschedule: {
      type: 'Optional[String]',
      desc: 'Defender day of the week for the system scan. Possible values are: userDefined, everyday, sunday, monday, tuesday, wednesday, thursday, friday, saturday.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wirelessdisplayblockprojectiontothisdevice: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to allow other devices from discovering this PC for projection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhidehibernate: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides hibernate from appearing in the power button in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_personalizationlockscreenimageurl: {
      type: 'Optional[String]',
      desc: 'A http or https Url to a jpg, jpeg or png image that neeeds to be downloaded and used as the Lock Screen Image or a file Url to a local image on the file system that needs to be used as the Lock Screen Image.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_networkproxyserver: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies manual proxy server settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_defendercloudblocklevel: {
      type: 'Optional[String]',
      desc: 'Specifies the level of cloud-delivered protection. Possible values are: notConfigured, high, highPlus, zeroTolerance.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edgeblockcompatibilitylist: {
      type: 'Optional[Boolean]',
      desc: 'Block Microsoft compatibility list in Microsoft Edge. This list from Microsoft helps Edge properly display sites with known compatibility issues.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchenableremotequeries: {
      type: 'Optional[Boolean]',
      desc: "Indicates whether or not to block remote queries of this computer's index.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_webrtcblocklocalhostipaddress: {
      type: 'Optional[Boolean]',
      desc: "Indicates whether or not user's localhost IP address is displayed while making phone calls using the WebRTC",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgehomepageurls: {
      type: 'Optional[Array[String]]',
      desc: 'The list of URLs for homepages shodwn on MDM-enrolled devices on Edge browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_cellularblockdatawhenroaming: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using data over cellular while roaming.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enterprisecloudprintmopriadiscoveryresourceidentifier: {
      type: 'Optional[String]',
      desc: 'OAuth resource URI for printer discovery service as configured in Azure portal.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfolderhomegroup: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the HomeGroup folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startmenumode: {
      type: 'Optional[String]',
      desc: 'Allows admins to decide how the Start menu is displayed. Possible values are: userDefined, fullScreen, nonFullScreen.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_settingsblockeditdevicename: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from editing the device name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfoldersettings: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Settings folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfoldernetwork: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Network folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_appsblockwindowsstoreoriginatedapps: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to disable the launch of all apps from Windows Store that came pre-installed or were downloaded.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockgamingpage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Gaming in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockupdatesecuritypage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Update & Security in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblockconsumerspecificfeatures: {
      type: 'Optional[Boolean]',
      desc: 'Allows IT admins to block experiences that are typically for consumers only, such as Start suggestions, Membership notifications, Post-OOBE app install and redirect tiles.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblocked: {
      type: 'Optional[Boolean]',
      desc: 'Allows IT admins to turn off all Windows Spotlight features',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockprivacypage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Privacy in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockpersonalizationpage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Personalization in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblocksettingsapp: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgefirstrunurl: {
      type: 'Optional[String]',
      desc: 'The first run URL for when Edge browser is opened for the first time.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_settingsblockaccountspage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Accounts in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defenderdetectedmalwareactions: {
      type: 'Optional[Array[String]]',
      desc: 'Gets or sets Defenders actions to take on detected Malware per threat level.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_defenderscheduledscantime: {
      type: 'Optional[String]',
      desc: 'The defender time for the system scan.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edgeenterprisemodesitelistlocation: {
      type: 'Optional[Boolean]',
      desc: 'Indicates the enterprise mode site list location. Could be a local file, local network or http location.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enterprisecloudprintdiscoveryendpoint: {
      type: 'Optional[String]',
      desc: 'Endpoint for discovering cloud printers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_searchdisableindexingencrypteditems: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block indexing of WIP-protected items to prevent them from appearing in search results for Cortana or Explorer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminimumcharactersetcount: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The number of character sets required in the password.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_edgeblockpasswordmanager: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block password manager.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_experienceblocktaskswitcher: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to enable task switching on the device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_gamedvrblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block DVR and broadcasting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockinprivatebrowsing: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block InPrivate browsing on corporate networks, in the Edge browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblocksendingdonottrackheader: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from sending the do not track header.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhideusertile: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides the user tile from appearing in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfolderdocuments: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Documents folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cellularblockvpnwhenroaming: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using VPN when roaming over cellular.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordsigninfailurecountbeforefactoryreset: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The number of sign in failures before factory reset. Valid values 0 to 999',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_accountsblockaddingnonmicrosoftaccountemail: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from adding email accounts to the device that are not associated with a Microsoft account.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_microsoftaccountblocksettingssync: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block Microsoft account settings sync.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_locationservicesblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from location services.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfolderfileexplorer: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the FileExplorer shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_settingsblocktimelanguagepage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Time & Language in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordexpirationdays: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The password expiration in days. Valid values 0 to 730',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfolderpictures: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Pictures folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordrequirewhenresumefromidlestate: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require a password upon resuming from an idle state.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsstoreblockautoupdate: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block automatic update of apps from Windows Store.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsstoreblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using the Windows store.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wifiblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using Wi-Fi.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Display name of the device configuration policy for Windows 10.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatesblockmanualrootcertificateinstallation: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from doing manual root certificate installation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsstoreenableprivatestoreonly: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to enable Private Store Only.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockjavascript: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using JavaScript.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenulayoutedgeassetsxml: {
      type: 'Optional[String]',
      desc: 'This policy setting allows you to import Edge assets to be used with startMenuLayoutXml policy. Start layout can contain secondary tile from Edge app which looks for Edge local asset file. Edge local asset would not exist and cause Edge secondary tile to appear empty in this case. This policy only gets applied when startMenuLayoutXml policy is modified. The value should be a UTF-8 Base64 encoded byte array.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defenderpromptforsamplesubmission: {
      type: 'Optional[String]',
      desc: 'The configuration for how to prompt user for sample submission. Possible values are: userDefined, alwaysPrompt, promptBeforeSendingPersonalData, neverSendData, sendAllDataWithoutPrompting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edgeblockaccesstoaboutflags: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to prevent access to about flags on Edge browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storageblockremovablestorage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using removable storage.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_lockscreenallowtimeoutconfiguration: {
      type: 'Optional[Boolean]',
      desc: 'Specify whether to show a user-configurable setting to control the screen timeout while on the lock screen of Windows 10 Mobile devices. If this policy is set to Allow, the value set by lockScreenTimeoutInSeconds is ignored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_experienceblockdevicediscovery: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to enable device discovery UX.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhiderestartoptions: {
      type: 'Optional[Boolean]',
      desc: "Enabling this policy hides 'Restart/Update and Restart' from appearing in the power button in the start menu.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_safesearchfilter: {
      type: 'Optional[String]',
      desc: 'Specifies what filter level of safe search is required. Possible values are: userDefined, strict, moderate.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_searchdisableindexingremovabledrive: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to allow users to add locations on removable drives to libraries and to be indexed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchblockdiacritics: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if search can use diacritics.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockremoveprovisioningpackage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the runtime configuration agent from removing provisioning packages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenupinnedfolderdownloads: {
      type: 'Optional[String]',
      desc: 'Enforces the visibility (Show/Hide) of the Downloads folder shortcut on the Start menu. Possible values are: notConfigured, hide, show.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_searchenableautomaticindexsizemanangement: {
      type: 'Optional[Boolean]',
      desc: 'Specifies minimum amount of hard drive space on the same drive as the index location before indexing stops.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockpopups: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block popups.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhidechangeaccountsettings: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides the change account setting from appearing in the user tile in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminimumlength: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The minimum password length. Valid values 4 to 16',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_settingsblockdevicespage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Devices in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_nfcblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using near field communication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantlockdownrequirenetworkduringoutofboxexperience: {
      type: 'Optional[Boolean]',
      desc: 'Whether the device is required to connect to the network.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscanscriptsloadedininternetexplorer: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan scripts loaded in Internet Explorer browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordminutesofinactivitybeforescreentimeout: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The minutes of inactivity before the screen times out.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_defenderscanremovabledrivesduringfullscan: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan removable drives during full scan.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_microsoftaccountblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block a Microsoft account.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_diagnosticsdatasubmissionmode: {
      type: 'Optional[String]',
      desc: 'Gets or sets a value allowing the device to send diagnostic and usage telemetry data, such as Watson. Possible values are: userDefined, none, basic, enhanced, full.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_settingsblockchangepowersleep: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from changing power and sleep settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockappspage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Apps in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using the Edge browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wifiblockautomaticconnecthotspots: {
      type: 'Optional[Boolean]',
      desc: 'Indicating whether or not to block automatically connecting to Wi-Fi hotspots. Has no impact if Wi-Fi is blocked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_copypasteblocked: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using copy paste.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wifiblockmanualconfiguration: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using Wi-Fi manual configuration.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_voicerecordingblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from voice recording.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhidesleep: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides sleep from appearing in the power button in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defendersignatureupdateintervalinhours: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The signature update interval in hours. Specify 0 not to check. Valid values 0 to 24',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_edgesyncfavoriteswithinternetexplorer: {
      type: 'Optional[Boolean]',
      desc: 'Enable favorites sync between Internet Explorer and Microsoft Edge. Additions, deletions, modifications and order changes to favorites are shared between browsers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_privacyadvertisingid: {
      type: 'Optional[String]',
      desc: 'Enables or disables the use of advertising ID. Added in Windows 10, version 1607. Possible values are: notConfigured, blocked, allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startmenuhidelock: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides lock from appearing in the user tile in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_privacyblockinputpersonalization: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the usage of cloud based speech services for Cortana, Dictation, or Store applications.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_cellularblockvpn: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using VPN over cellular.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bluetoothblockdiscoverablemode: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using bluetooth discoverable mode.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderfileextensionstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'File extensions to exclude from scans and real time protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_defendermonitorfileactivity: {
      type: 'Optional[String]',
      desc: 'Value for monitoring file activity. Possible values are: userDefined, disable, monitorAllFiles, monitorIncomingFilesOnly, monitorOutgoingFilesOnly.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_antitheftmodeblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from selecting an AntiTheft mode preference (Windows 10 Mobile only).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockchangelanguage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from changing the language settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enterprisecloudprintoauthclientidentifier: {
      type: 'Optional[String]',
      desc: 'GUID of a client application authorized to retrieve OAuth tokens from the OAuth Authority.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblockthirdpartynotifications: {
      type: 'Optional[Boolean]',
      desc: 'Block third party content delivered via Windows Spotlight',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_developerunlocksetting: {
      type: 'Optional[String]',
      desc: 'Indicates whether or not to allow developer unlock. Possible values are: notConfigured, blocked, allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_lockscreentimeoutinseconds: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Set the duration (in seconds) from the screen locking to the screen turning off for Windows 10 Mobile devices. Supported values are 11-1800. Valid values 11 to 1800',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_searchdisableindexerbackoff: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to disable the search indexer backoff feature.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Active Directory tenant used for authentication. Format contoso.onmicrosoft.com',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edgecookiepolicy: {
      type: 'Optional[String]',
      desc: 'Indicates which cookies to block in the Edge browser. Possible values are: userDefined, allow, blockThirdParty, blockAll.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startmenuhideswitchaccount: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides switch account from appearing in the user tile in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderblockenduseraccess: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to block end user access to Defender.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderrequirenetworkinspectionsystem: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require network inspection system.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_smartscreenblockpromptoverrideforfiles: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not users can override the SmartScreen Filter warnings about downloading unverified files',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderrequirecloudprotection: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require cloud protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderfilesandfolderstoexclude: {
      type: 'Optional[Array[String]]',
      desc: 'Files and folder to exclude from scans and real time protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_resetprotectionmodeblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from reset protection mode.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startblockunpinningappsfromtaskbar: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from unpinning apps from taskbar.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bluetoothallowedservices: {
      type: 'Optional[Array[String]]',
      desc: 'Specify a list of allowed Bluetooth services and profiles in hex formatted strings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_defenderscanarchivefiles: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan archive files.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscanincomingmail: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan incoming mail messages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightconfigureonlockscreen: {
      type: 'Optional[String]',
      desc: 'Specifies the type of Spotlight. Possible values are: notConfigured, disabled, enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_lockscreenblockcortana: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not the user can interact with Cortana using speech while the system is locked.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuapplistvisibility: {
      type: 'Optional[String]',
      desc: 'Setting the value of this collapses the app list, removes the app list entirely, or disables the corresponding toggle in the Settings app. Possible values are: userDefined, collapse, remove, disableSettingsApp.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_screencaptureblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from taking Screenshots.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_devicemanagementblockfactoryresetonmobile: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from resetting their phone.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'String',
      desc: 'Description of the device configuration policy for Windows 10.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edgerequiresmartscreen: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Require the user to use the smart screen filter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockaddprovisioningpackage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from installing provisioning packages.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockautofill: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block auto fill.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblocknetworkinternetpage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Network & Internet in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usbblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from USB connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscheduledquickscantime: {
      type: 'Optional[String]',
      desc: 'The time to perform a daily quick scan.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_onedrivedisablefilesync: {
      type: 'Optional[Boolean]',
      desc: 'Gets or sets a value allowing IT admins to prevent apps and features from working with files on OneDrive.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enterprisecloudprintoauthauthority: {
      type: 'Optional[String]',
      desc: 'Authentication endpoint for acquiring OAuth tokens.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Intune Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_startmenulayoutxml: {
      type: 'Optional[String]',
      desc: 'Allows admins to override the default Start menu layout and prevents the user from changing it. The layout is modified by specifying an XML file based on a layout modification schema. XML needs to be in a UTF8 encoded byte array format.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wirelessdisplayrequirepinforpairing: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require a PIN for new devices to initiate pairing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgesendintranettraffictointernetexplorer: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to switch the intranet traffic from Edge to Internet Explorer.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_edgeblocklivetiledatacollection: {
      type: 'Optional[Boolean]',
      desc: 'Block the collection of information by Microsoft for live tile creation when users pin a site to Start from Microsoft Edge.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_networkproxyapplysettingsdevicewide: {
      type: 'Optional[Boolean]',
      desc: 'If set, proxy settings will be applied to all processes and accounts in the device. Otherwise, it will be applied to the user account thats enrolled into MDM.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchdisableautolanguagedetection: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to use automatic language detection when indexing content and properties.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeallowstartpagesmodification: {
      type: 'Optional[Boolean]',
      desc: 'Allow users to change Start pages on Edge. Use the EdgeHomepageUrls to specify the Start pages that the user would see by default when they open Edge.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storagerequiremobiledeviceencryption: {
      type: 'Optional[Boolean]',
      desc: 'Indicating whether or not to require encryption on a mobile device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderrequirerealtimemonitoring: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require real time monitoring.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_wifiscaninterval: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Specify how often devices scan for Wi-Fi networks. Supported values are 1-500, where 100 = default, and 500 = low frequency. Valid values 1 to 500',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_camerablocked: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from accessing the camera of the device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_networkproxydisableautodetect: {
      type: 'Optional[Boolean]',
      desc: 'Disable automatic detection of settings. If enabled, the system will try to find the path to a proxy auto-config (PAC) script.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_logonblockfastuserswitching: {
      type: 'Optional[Boolean]',
      desc: 'Disables the ability to quickly switch between users that are logged on simultaneously without logging off.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enterprisecloudprintdiscoverymaxlimit: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Maximum number of printers that should be queried from a discovery endpoint. This is a mobile only setting. Valid values 1 to 65535',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_bluetoothblockadvertising: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to Block the user from using bluetooth advertising.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscantype: {
      type: 'Optional[String]',
      desc: 'The defender system scan type. Possible values are: userDefined, disabled, quick, full.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_edgeblocksendingintranettraffictointernetexplorer: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to switch the intranet traffic from Edge to Internet Explorer. Note: the name of this property is misleading; the property is obsolete, use EdgeSendIntranetTrafficToInternetExplorer instead.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_smartscreenblockpromptoverride: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not users can override SmartScreen Filter warnings about potentially malicious websites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscanmappednetworkdrivesduringfullscan: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan mapped network drives during full scan.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_lockscreenblocktoastnotifications: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether to allow toast notifications above the device lock screen.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_storagerestrictappinstalltosystemvolume: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the installation of applications is restricted to the system drive.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhideshutdown: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides shut down/update and shut down from appearing in the power button in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblockwelcomeexperience: {
      type: 'Optional[Boolean]',
      desc: 'Block Windows Spotlight Windows welcome experience',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderscandownloads: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to scan downloads.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblockonactioncenter: {
      type: 'Optional[Boolean]',
      desc: 'Block suggestions from Microsoft that show after each OS clean install, upgrade or in an on-going basis to introduce users to what is new or changed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defenderdaysbeforedeletingquarantinedmalware: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Number of days before deleting quarantined malware. Valid values 0 to 90',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_privacyautoacceptpairingandconsentprompts: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to allow the automatic acceptance of the pairing and privacy user consent dialog when launching apps.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_settingsblockchangeregion: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from changing the region settings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblocksearchsuggestions: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block the user from using the search suggestions in the address bar.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the site collection exists, absent ensures it is removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defenderrequirebehaviormonitoring: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to require behavior monitoring.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_shareduserappdataallowed: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block multiple users of the same app to share data.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_windowsspotlightblockwindowstips: {
      type: 'Optional[Boolean]',
      desc: 'Allows IT admins to turn off the popup of Windows Tips.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhiderecentlyaddedapps: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides recently added apps from appearing on the start menu and disables the corresponding toggle in the Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_personalizationdesktopimageurl: {
      type: 'Optional[String]',
      desc: 'A http or https Url to a jpg, jpeg or png image that needs to be downloaded and used as the Desktop Image or a file Url to a local image on the file system that needs to used as the Desktop Image.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_networkproxyautomaticconfigurationurl: {
      type: 'Optional[String]',
      desc: 'Address to the proxy auto-config (PAC) script you want to use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_startmenuhidepowerbutton: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides the power button from appearing in the start menu.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_internetsharingblocked: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to Block the user from using internet sharing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_bluetoothblockprepairing: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to block specific bundled Bluetooth peripherals to automatically pair with the host device.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_startmenuhidefrequentlyusedapps: {
      type: 'Optional[Boolean]',
      desc: 'Enabling this policy hides the most used apps from appearing on the start menu and disables the corresponding toggle in the Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockdevelopertools: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block developer tools in the Edge browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockaddressbardropdown: {
      type: 'Optional[Boolean]',
      desc: 'Block the address bar dropdown functionality in Microsoft Edge. Disable this settings to minimize network connections from Microsoft Edge to Microsoft services.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgeblockextensions: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block extensions in the Edge browser.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_connecteddevicesserviceblocked: {
      type: 'Optional[Boolean]',
      desc: 'Whether or not to block Connected Devices Service which enables discovery and connection to other devices, remote messaging, remote app sessions and other cross-device experiences.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_passwordrequiredtype: {
      type: 'Optional[String]',
      desc: 'The required password type. Possible values are: deviceDefault, alphanumeric, numeric.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_settingsblockeaseofaccesspage: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not to block access to Ease of Access in Settings app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_edgesearchengine: {
      type: 'Optional[String]',
      desc: 'Allows IT admins to set a default search engine for MDM-Controlled devices. Users can override this and change their default search engine provided the AllowSearchEngineCustomization policy is not set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
