require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_o365user',
  dscmeta_resource_friendly_name: 'O365User',
  dscmeta_resource_name: 'MSFT_O365User',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC O365User resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_postalcode: {
      type: 'Optional[String]',
      desc: 'The Postal Code of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory application used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_department: {
      type: 'Optional[String]',
      desc: 'The Department name of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_office: {
      type: 'Optional[String]',
      desc: 'The Office Name of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'The display name for the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_password: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The password for the account. The parameter is a PSCredential object, but only the Password component will be used',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_userprincipalname: {
      type: 'String',
      desc: 'The login name of the user',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usagelocation: {
      type: 'Optional[String]',
      desc: 'The country code the user will be assigned to',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_passwordneverexpires: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the user password expires periodically. Default value is false',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_licenseassignment: {
      type: 'Optional[Array[String]]',
      desc: 'The account SKU Id for the license to be assigned to the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_fax: {
      type: 'Optional[String]',
      desc: 'The Fax Number of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_lastname: {
      type: 'Optional[String]',
      desc: 'The last name of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usertype: {
      type: "Optional[Enum['Guest', 'Member', 'Other', 'Viral']]",
      desc: 'Specifies the title of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_country: {
      type: 'Optional[String]',
      desc: 'The Country name of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Active Directory tenant used for authentication. Format contoso.onmicrosoft.com',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_preferredlanguage: {
      type: 'Optional[String]',
      desc: 'The Prefered Language of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_state: {
      type: 'Optional[String]',
      desc: 'Specifies the state or province where the user is located',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_city: {
      type: 'Optional[String]',
      desc: 'The City name of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_title: {
      type: 'Optional[String]',
      desc: 'Specifies the title of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_mobilephone: {
      type: 'Optional[String]',
      desc: 'The Mobile Phone Number of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the user exists, absent ensures it is removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_preferreddatalocation: {
      type: 'Optional[String]',
      desc: 'The Prefered location to store data of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_streetaddress: {
      type: 'Optional[String]',
      desc: 'Specifies the street address of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_phonenumber: {
      type: 'Optional[String]',
      desc: 'The Phone Number of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_firstname: {
      type: 'Optional[String]',
      desc: 'The first name of the user',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
