require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_plannertask',
  dscmeta_resource_friendly_name: 'PlannerTask',
  dscmeta_resource_name: 'MSFT_PlannerTask',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC PlannerTask resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_planid: {
      type: 'String',
      desc: 'Id of the Planner Plan which contains the Task.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_checklist: {
      type: 'Optional[Array[Struct[{
              title => Optional[String],
              completed => Optional[String],
            }]]]',
      desc: 'List checklist items associated with the task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_PlannerTaskChecklistItem[]',
      mof_is_embedded: true,
    },
    dsc_categories: {
      type: "Optional[Array[Enum['Pink', 'Red', 'Yellow', 'Green', 'Blue', 'Purple']]]",
      desc: 'List of categories assigned to the task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_startdatetime: {
      type: 'Optional[String]',
      desc: 'Date and Time for the start of the Task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_priority: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Priority of the Task. Value can only be between 1 and 10.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_assignedusers: {
      type: 'Optional[Array[String]]',
      desc: "List of users assigned to the tasks (ex: @('john.smith@contoso.com', 'bob.houle@contoso.com')).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_notes: {
      type: 'Optional[String]',
      desc: 'Description of the Task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the Plan exists, absent ensures it is removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_percentcomplete: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Percentage completed of the Task. Value can only be between 0 and 100.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_taskid: {
      type: 'Optional[String]',
      desc: 'Id of the Task, if known.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_duedatetime: {
      type: 'Optional[String]',
      desc: 'Date and Time for the task is due for completion.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_title: {
      type: 'String',
      desc: 'The Title of the Planner Task.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_attachments: {
      type: "Optional[Array[Struct[{
              alias => Optional[String],
              type => Optional[Enum['PowerPoint', 'Word', 'Excel', 'Other']],
              uri => Optional[String]
            }]]]",
      desc: 'List of links to attachments assigned to the task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_PlannerTaskAttachment[]',
      mof_is_embedded: true,
    },
    dsc_conversationthreadid: {
      type: 'Optional[String]',
      desc: 'Id of the group conversation thread associated with the comments section for this task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_bucket: {
      type: 'Optional[String]',
      desc: 'The Id of the bucket that contains the task.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
