require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_pptenantsettings',
  dscmeta_resource_friendly_name: 'PPTenantSettings',
  dscmeta_resource_name: 'MSFT_PPTenantSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC PPTenantSettings resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_disablenewslettersendout: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable the monthly newsletters.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disableenvironmentcreationbynonadminusers: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable production environment creation by non-admin users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disablesurveyfeedback: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable survey feedback that sometimes pops up on top of an app.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disablecommunitysearch: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable community search in the Office 365 Suite navigation bar.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_walkmeoptout: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable the Walk Me guidance.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Power Platform Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_disableportalscreationbynonadminusers: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable portal creation by non-admin users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disabletrialenvironmentcreationbynonadminusers: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable trial environment creation by non-admin users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disablecapacityallocationbyenvironmentadmins: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable capacity allocation by environment admins.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disablebingvideosearch: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable Bing video search in the Office 365 Suite navigation bar.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sharewithcolleaguesuserlimit: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The amount of people an app can be shared with in Dataverse for Teams (maximum is 10,000).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_disablesupportticketsvisiblebyallusers: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable support tickets to be visible by all users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: 'Should be set to yes',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disablesharewitheveryone: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable the ability to share apps with the whole tenant.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disabledocssearch: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable docs search in the Office 365 Suite navigation bar.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablegueststomake: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will enable the ability for guests in your tenant to create Power Platform resources.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disablenpscommentsreachout: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable the NPS Comments Reachout.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
