require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sccaseholdrule',
  dscmeta_resource_friendly_name: 'SCCaseHoldRule',
  dscmeta_resource_name: 'MSFT_SCCaseHoldRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCCaseHoldRule resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'The Comment parameter specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_contentmatchquery: {
      type: 'Optional[String]',
      desc: "The ContentMatchQuery parameter specifies a content search filter. Use this parameter to create a query-based hold so only the content that matches the specified search query is placed on hold. This parameter uses a text search string or a query that's formatted by using the Keyword Query Language (KQL).",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the rule exists, absent ensures it is removed',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disabled: {
      type: 'Optional[Boolean]',
      desc: 'The Disabled parameter specifies whether the case hold rule is enabled or disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_policy: {
      type: 'String',
      desc: 'The Policy parameter specifies the case hold policy that contains the rule. You can use any value that uniquely identifies the policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies a unique name for the case hold rule.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Global Admin Account',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
