require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sccompliancesearchaction',
  dscmeta_resource_friendly_name: 'SCComplianceSearchAction',
  dscmeta_resource_name: 'MSFT_SCComplianceSearchAction',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCComplianceSearchAction resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_includesharepointdocumentversions: {
      type: 'Optional[Boolean]',
      desc: 'The IncludeSharePointDocumentVersions parameter specifies whether to export previous versions of the document when you use the Export switch.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_action: {
      type: "Enum['Export', 'Preview', 'Purge', 'Retention']",
      desc: 'The Action parameter specifies what type of action to define. Accepted values are Export, Retention and Purge.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_filetypeexclusionsforunindexeditems: {
      type: 'Optional[Array[String]]',
      desc: "The FileTypeExclusionsForUnindexedItems specifies the file types to exclude because they can't be indexed. You can specify multiple values separated by commas.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this action should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablededupe: {
      type: 'Optional[Boolean]',
      desc: 'The EnableDedupe parameter eliminates duplication of messages when you export content search results.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_purgetype: {
      type: "Optional[Enum['SoftDelete', 'HardDelete']]",
      desc: 'The PurgeType parameter specifies how to remove items when the action is Purge.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retryonerror: {
      type: 'Optional[Boolean]',
      desc: 'The RetryOnError switch specifies whether to retry the action on any items that failed without re-running the entire action all over again.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_actionscope: {
      type: "Optional[Enum['IndexedItemsOnly', 'UnindexedItemsOnly', 'BothIndexedAndUnindexedItems']]",
      desc: 'The ActionScope parameter specifies the items to include when the action is Export.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_includecredential: {
      type: 'Optional[Boolean]',
      desc: 'The IncludeCredential switch specifies whether to include the credential in the results.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchname: {
      type: 'String',
      desc: 'The SearchName parameter specifies the name of the existing content search to associate with the content search action. You can specify multiple content searches separated by commas.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
