require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sccompliancetag',
  dscmeta_resource_friendly_name: 'SCComplianceTag',
  dscmeta_resource_name: 'MSFT_SCComplianceTag',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCComplianceTag resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_fileplanproperty: {
      type: 'Optional[Struct[{
              fileplanpropertycitation => Optional[String],
              fileplanpropertyauthority => Optional[String],
              fileplanpropertycategory => Optional[String],
              fileplanpropertydepartment => Optional[String],
              fileplanpropertyreferenceid => Optional[String],
              fileplanpropertysubcategory => Optional[String]
            }]]',
      desc: 'The FilePlanProperty parameter specifies the file plan properties to include in the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SCFilePlanProperty',
      mof_is_embedded: true,
    },
    dsc_retentionduration: {
      type: 'Optional[String]',
      desc: 'The RetentionDuration parameter specifies the hold duration for the retention rule. Valid values are: An integer - The hold duration in days, Unlimited - The content is held indefinitely.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isrecordlabel: {
      type: 'Optional[Boolean]',
      desc: 'The IsRecordLabel parameter specifies whether the label is a record label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the unique name of the complaiance tag.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_notes: {
      type: 'Optional[String]',
      desc: "The Notes parameter specifies an optional note. If you specify a value that contains spaces, enclose the value in quotation marks, for example: 'This is a user note'",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this rule should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'The Comment parameter specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retentiontype: {
      type: "Optional[Enum['CreationAgeInDays', 'EventAgeInDays', 'ModificationAgeInDays', 'TaggedAgeInDays']]",
      desc: 'The RetentionType parameter specifies whether the retention duration is calculated from the content creation date, tagged date, or last modification date. Valid values are: CreationAgeInDays, EventAgeInDays,ModificationAgeInDays, or TaggedAgeInDays.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_eventtype: {
      type: 'Optional[String]',
      desc: "The EventType parameter specifies the retention rule that's associated with the label.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retentionaction: {
      type: "Optional[Enum['Delete', 'Keep', 'KeepAndDelete']]",
      desc: 'The RetentionAction parameter specifies the action for the label. Valid values are: Delete, Keep or KeepAndDelete.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_regulatory: {
      type: 'Optional[Boolean]',
      desc: 'Regulatory description',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_revieweremail: {
      type: 'Optional[Array[String]]',
      desc: 'The ReviewerEmail parameter specifies the email address of a reviewer for Delete and KeepAndDelete retention actions. You can specify multiple email addresses separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
