require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_scdlpcompliancerule',
  dscmeta_resource_friendly_name: 'SCDLPComplianceRule',
  dscmeta_resource_name: 'MSFT_SCDLPComplianceRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCDLPComplianceRule resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_stoppolicyprocessing: {
      type: 'Optional[Boolean]',
      desc: 'The StopPolicyProcessing parameter specifies an action that stops processing more DLP policy rules.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_notifyuser: {
      type: 'Optional[Array[String]]',
      desc: 'The NotifyUser parameter specifies an action for the DLP rule that notifies the specified users when the conditions of the rule are met.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifprocessinglimitexceeded: {
      type: 'Optional[Boolean]',
      desc: "The ExceptIfProcessingLimitExceeded parameter specifies an exception for the DLP rule that looks for files where scanning couldn't complete.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifcontentcontainssensitiveinformation: {
      type: "Optional[Struct[{
              sensitiveinformation => Array[Struct[{
                cim_instance_type => Enum['MSFT_SCDLPSensitiveInformation'],
                name => String,
                id => Optional[String],
                minconfidence => Optional[String],
                classifiertype => Optional[String],
                maxconfidence => Optional[String],
                mincount => Optional[String],
                maxcount => Optional[String]
              }]],
              operator => Optional[Enum['And', 'Or']],
              groups => Array[Struct[{
                operator => Enum['And', 'Or'],
                labels => Array[Struct[{
                  type => Optional[String],
                  name => String,
                  id => Optional[String],
                  cim_instance_type => Enum['MSFT_SCDLPLabel']
                }]],
                name => String,
                cim_instance_type => Enum['MSFT_SCDLPContainsSensitiveInformationGroup'],
                sensitiveinformation => Array[Struct[{
                  cim_instance_type => Enum['MSFT_SCDLPSensitiveInformation'],
                  name => String,
                  id => Optional[String],
                  minconfidence => Optional[String],
                  classifiertype => Optional[String],
                  maxconfidence => Optional[String],
                  mincount => Optional[String],
                  maxcount => Optional[String]
                }]]
              }]],
            }]]",
      desc: "The ExceptIfContentContainsSensitiveInformation parameter specifies an exception for the rule that's based on a sensitive information type match in content. The rule isn't applied to content that contains the specified sensitive information type.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SCDLPContainsSensitiveInformation',
      mof_is_embedded: true,
    },
    dsc_processinglimitexceeded: {
      type: 'Optional[Boolean]',
      desc: "The ProcessingLimitExceeded parameter specifies a condition for the DLP rule that looks for files where scanning couldn't complete.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_hassenderoverride: {
      type: 'Optional[Boolean]',
      desc: 'The SenderOverride parameter specifies a condition for the rule that looks for messages where the sender chose to override a DLP policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_exceptifdocumentisunsupported: {
      type: 'Optional[Boolean]',
      desc: "The ExceptIfDocumentIsUnsupported parameter specifies an exception for the DLP rule that looks for files that can't be scanned.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_incidentreportcontent: {
      type: "Optional[Array[Enum['All', 'Default', 'DetectionDetails', 'Detections', 'DocumentAuthor', 'DocumentLastModifier', 'MatchedItem', 'OriginalContent', 'RulesMatched', 'Service', 'Severity', 'Title', 'RetentionLabel', 'SensitivityLabel']]]",
      desc: 'The IncidentReportContent parameter specifies the content to include in the report when you use the GenerateIncidentReport parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_generateincidentreport: {
      type: 'Optional[Array[String]]',
      desc: 'The GenerateIncidentReport parameter specifies an action for the DLP rule that sends an incident report to the specified users when the conditions of the rule are met.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifhassenderoverride: {
      type: 'Optional[Boolean]',
      desc: 'The ExceptIfHasSenderOverride parameter specifies an exception for the rule that looks for messages where the sender chose to override a DLP policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_policy: {
      type: 'String',
      desc: 'Name of the associated DLP Compliance Policy.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifcontentextensionmatcheswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfContentExtensionMatchesWords parameter specifies an exception for the DLP rule that looks for words in file name extensions. You can specify multiple words separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_removermstemplate: {
      type: 'Optional[Boolean]',
      desc: 'The RemoveRMSTemplate parameter specifies an action for the DLP rule that removes Office 365 Message Encryption from messages and their attachments.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_notifyemailcustomtext: {
      type: 'Optional[String]',
      desc: "The NotifyEmailCustomText parameter specifies the custom text in the email notification message that's sent to recipients when the conditions of the rule are met.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_generatealert: {
      type: 'Optional[Array[String]]',
      desc: 'The GenerateAlert parameter specifies an action for the DLP rule that notifies the specified users when the conditions of the rule are met.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'The Comment parameter specifies an optional comment. If you specify a value that contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_anyofrecipientaddresscontainswords: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfRecipientAddressContainsWords parameter specifies a condition for the DLP rule that looks for words or phrases in recipient email addresses.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_reportseveritylevel: {
      type: "Optional[Enum['Low', 'Medium', 'High', 'None']]",
      desc: 'The ReportSeverityLevel parameter specifies the severity level of the incident report for content detections based on the rule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_contentpropertycontainswords: {
      type: 'Optional[Array[String]]',
      desc: "The ContentPropertyContainsWords parameter specifies a condition for the DLP rule that's based on a property match in content. The rule is applied to content that contains the specified property.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_anyofrecipientaddressmatchespatterns: {
      type: 'Optional[Array[String]]',
      desc: 'The AnyOfRecipientAddressMatchesPatterns parameter specifies a condition for the DLP rule that looks for text patterns in recipient email addresses by using regular expressions..',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_contentextensionmatcheswords: {
      type: 'Optional[Array[String]]',
      desc: 'The ContentExtensionMatchesWords parameter specifies a condition for the DLP rule that looks for words in file name extensions. You can specify multiple words separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this rule should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_documentisunsupported: {
      type: 'Optional[Boolean]',
      desc: "The DocumentIsUnsupported parameter specifies a condition for the DLP rule that looks for files that can't be scanned.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disabled: {
      type: 'Optional[Boolean]',
      desc: 'The Disabled parameter specifies whether the DLP rule is disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ruleerroraction: {
      type: "Optional[Enum['Ignore', 'RetryThenBlock']]",
      desc: 'The RuleErrorAction parameter specifies what to do if an error is encountered during the evaluation of the rule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_blockaccess: {
      type: 'Optional[Boolean]',
      desc: 'The BlockAccess parameter specifies an action for the DLP rule that blocks access to the source item when the conditions of the rule are met. $true: Blocks further access to the source item that matched the rule. The owner, author, and site owner can still access the item. $false: Allows access to the source item that matched the rule. This is the default value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_accessscope: {
      type: "Optional[Array[Enum['InOrganization', 'NotInOrganization', 'None']]]",
      desc: "The AccessScope parameter specifies a condition for the DLP rule that's based on the access scope of the content. The rule is applied to content that matches the specified access scope.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_contentcontainssensitiveinformation: {
      type: "Optional[Struct[{
              sensitiveinformation => Array[Struct[{
                cim_instance_type => Enum['MSFT_SCDLPSensitiveInformation'],
                name => String,
                id => Optional[String],
                minconfidence => Optional[String],
                classifiertype => Optional[String],
                maxconfidence => Optional[String],
                mincount => Optional[String],
                maxcount => Optional[String]
              }]],
              operator => Optional[Enum['And', 'Or']],
              groups => Array[Struct[{
                operator => Enum['And', 'Or'],
                labels => Array[Struct[{
                  type => Optional[String],
                  name => String,
                  id => Optional[String],
                  cim_instance_type => Enum['MSFT_SCDLPLabel']
                }]],
                name => String,
                cim_instance_type => Enum['MSFT_SCDLPContainsSensitiveInformationGroup'],
                sensitiveinformation => Array[Struct[{
                  cim_instance_type => Enum['MSFT_SCDLPSensitiveInformation'],
                  name => String,
                  id => Optional[String],
                  minconfidence => Optional[String],
                  classifiertype => Optional[String],
                  maxconfidence => Optional[String],
                  mincount => Optional[String],
                  maxcount => Optional[String]
                }]]
              }]],
            }]]",
      desc: "The ContentContainsSensitiveInformation parameter specifies a condition for the rule that's based on a sensitive information type match in content. The rule is applied to content that contains the specified sensitive information type.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SCDLPContainsSensitiveInformation',
      mof_is_embedded: true,
    },
    dsc_documentispasswordprotected: {
      type: 'Optional[Boolean]',
      desc: "The DocumentIsPasswordProtected parameter specifies a condition for the DLP rule that looks for password protected files (because the contents of the file can't be inspected). Password detection only works for Office documents and .zip files.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_notifypolicytipcustomtext: {
      type: 'Optional[String]',
      desc: "The NotifyPolicyTipCustomText parameter specifies the custom text in the Policy Tip notification message that's shown to recipients when the conditions of the rule are met. The maximum length is 256 characters. HTML tags and tokens (variables) aren't supported.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_notifyallowoverride: {
      type: "Optional[Array[Enum['FalsePositive', 'WithoutJustification', 'WithJustification']]]",
      desc: 'The NotifyAllowOverride parameter specifies the notification override options when the conditions of the rule are met.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the Rule.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_blockaccessscope: {
      type: "Optional[Enum['All', 'PerUser']]",
      desc: 'The BlockAccessScope parameter specifies the scope of the block access action.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifdocumentispasswordprotected: {
      type: 'Optional[Boolean]',
      desc: "The ExceptIfDocumentIsPasswordProtected parameter specifies an exception for the DLP rule that looks for password protected files (because the contents of the file can't be inspected). Password detection only works for Office documents and .zip files. ",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
