require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sclabelpolicy',
  dscmeta_resource_friendly_name: 'SCLabelPolicy',
  dscmeta_resource_name: 'MSFT_SCLabelPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCLabelPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_addmoderngrouplocationexception: {
      type: 'Optional[Array[String]]',
      desc: "The AddModernGroupLocationException parameter specifies the Microsoft 365 Groups to add to exclusions when you're using the value All for the ModernGroupLocation parameter.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_labels: {
      type: 'Optional[Array[String]]',
      desc: 'The Labels parameter specifies the sensitivity labels that are associated with the policy. You can use any value that uniquely identifies the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the unique name for the sensitivity label. The maximum length is 64 characters. If the value contains spaces, enclose the value in quotation marks.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_moderngrouplocation: {
      type: 'Optional[Array[String]]',
      desc: 'The ModernGroupLocation parameter specifies the Microsoft 365 Groups to include in the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_removeexchangelocation: {
      type: 'Optional[Array[String]]',
      desc: 'The RemoveExchangeLocation parameter specifies the mailboxes to remove from the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_addexchangelocation: {
      type: 'Optional[Array[String]]',
      desc: 'The AddExchangeLocation parameter specifies the mailboxes to add in the existing policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_removelabels: {
      type: 'Optional[Array[String]]',
      desc: 'The RemoveLabels parameter specifies the sensitivity labels that are removed from the policy. You can use any value that uniquely identifies the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_exchangelocation: {
      type: 'Optional[Array[String]]',
      desc: 'The ExchangeLocation parameter specifies the mailboxes to include in the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this label policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'The Comment parameter specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exchangelocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'The ExchangeLocationException parameter specifies the mailboxes to exclude when you use the value All for the ExchangeLocation parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_moderngrouplocationexception: {
      type: 'Optional[Array[String]]',
      desc: "The ModernGroupLocationException parameter specifies the Microsoft 365 Groups to exclude when you're using the value All for the ModernGroupLocation parameter.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_addmoderngrouplocation: {
      type: 'Optional[Array[String]]',
      desc: 'The AddModernGroupLocation parameter specifies the Microsoft 365 Groups to add to include the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_removeexchangelocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'The RemoveExchangeLocationException parameter specifies the mailboxes to remove when you use the value All for the ExchangeLocation parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_removemoderngrouplocationexception: {
      type: 'Optional[Array[String]]',
      desc: "The RemoveModernGroupLocationException parameter specifies the Microsoft 365 Groups to remove from excluded values when you're using the value All for the ModernGroupLocation parameter.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_addlabels: {
      type: 'Optional[Array[String]]',
      desc: 'The AddLabels parameter specifies the sensitivity labels to add to the policy. You can use any value that uniquely identifies the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_advancedsettings: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[Array[String]],
            }]]]',
      desc: 'The AdvancedSettings parameter enables client-specific features and capabilities on the sensitivity label. The settings that you configure with this parameter only affect apps that are designed for the setting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SCLabelSetting[]',
      mof_is_embedded: true,
    },
    dsc_addexchangelocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'The AddExchangeLocationException parameter specifies the mailboxes to add to exclusions when you use the value All for the ExchangeLocation parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_removemoderngrouplocation: {
      type: 'Optional[Array[String]]',
      desc: 'The RemoveModernGroupLocation parameter specifies the Microsoft 365 Groups to remove from the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
