require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_scretentioncompliancepolicy',
  dscmeta_resource_friendly_name: 'SCRetentionCompliancePolicy',
  dscmeta_resource_name: 'MSFT_SCRetentionCompliancePolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCRetentionCompliancePolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'The Comment parameter specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_moderngrouplocation: {
      type: 'Optional[Array[String]]',
      desc: 'The ModernGroupLocation parameter specifies the Office 365 groups to include in the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_onedrivelocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter specifies the OneDrive for Business sites to exclude when you use the value All for the OneDriveLocation parameter. You identify the site by its URL value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_teamschatlocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter specifies the SharePoint Online sites to exclude when you use the value All for the TeamsChatLocation parameter. You identify the site by its URL value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the unique name of the retention policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_teamschatlocation: {
      type: 'Optional[Array[String]]',
      desc: 'The TeamsChatLocation parameter specifies the Teams Chat to include in the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_teamschannellocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter specifies the SharePoint Online sites to exclude when you use the value All for the TeamsChannelLocation parameter. You identify the site by its URL value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_publicfolderlocation: {
      type: 'Optional[Array[String]]',
      desc: 'The PublicFolderLocation parameter specifies that you want to include all public folders in the retention policy. You use the value All for this parameter.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_restrictiveretention: {
      type: 'Optional[Boolean]',
      desc: 'The RestrictiveRetention parameter specifies whether Preservation Lock is enabled for the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_exchangelocation: {
      type: 'Optional[Array[String]]',
      desc: 'The ExchangeLocation parameter specifies the mailboxes to include.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_onedrivelocation: {
      type: 'Optional[Array[String]]',
      desc: 'The OneDriveLocation parameter specifies the OneDrive for Business sites to include. You identify the site by its URL value, or you can use the value All to include all sites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this policy should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_moderngrouplocationexception: {
      type: 'Optional[Array[String]]',
      desc: "The ModernGroupLocationException parameter specifies the Office 365 groups to exclude when you're using the value All for the ModernGroupLocation parameter.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exchangelocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter specifies the mailboxes to remove from the list of excluded mailboxes when you use the value All for the ExchangeLocation parameter',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_dynamicscopelocation: {
      type: 'Optional[Array[String]]',
      desc: 'Location of the dynamic scope for this policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_teamschannellocation: {
      type: 'Optional[Array[String]]',
      desc: 'The TeamsChannelLocation parameter specifies the Teams Channel to include in the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sharepointlocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter specifies the SharePoint Online sites to exclude when you use the value All for the SharePointLocation parameter. You identify the site by its URL value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_sharepointlocation: {
      type: 'Optional[Array[String]]',
      desc: 'The SharePointLocation parameter specifies the SharePoint Online sites to include. You identify the site by its URL value, or you can use the value All to include all sites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_skypelocation: {
      type: 'Optional[Array[String]]',
      desc: 'The SkypeLocation parameter specifies the Skype for Business Online users to include in the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'Determines if the policy is enabled or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_skypelocationexception: {
      type: 'Optional[Array[String]]',
      desc: 'This parameter is reserved for internal Microsoft use.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
