require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_scsensitivitylabel',
  dscmeta_resource_friendly_name: 'SCSensitivityLabel',
  dscmeta_resource_name: 'MSFT_SCSensitivityLabel',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SCSensitivityLabel resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_applycontentmarkingheaderfontsize: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The ApplyContentMarkingFooterFontSize parameter specifies the font size (in points) of the header text.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_encryptionrightsdefinitions: {
      type: 'Optional[String]',
      desc: 'The EncryptionRightsDefinitions parameter specifies the rights users have when accessing protected. This parameter uses the syntax Identity1:Rights1,Rights2;Identity2:Rights3,Rights4. For example, john@contoso.com:VIEW,EDIT;microsoft.com:VIEW.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteandgroupprotectionblockaccess: {
      type: 'Optional[Boolean]',
      desc: 'The SiteAndGroupProtectionBlockAccess parameter blocks access.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applywatermarkingtext: {
      type: 'Optional[String]',
      desc: 'The ApplyWaterMarkingText parameter specifies the watermark text. If the value contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingfootermargin: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The ApplyContentMarkingFooterMargin parameter specifies the size (in points) of the footer margin.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_applywatermarkingfontcolor: {
      type: 'Optional[String]',
      desc: 'The ApplyWaterMarkingFontColor parameter specifies the color of the watermark text. This parameter accepts a hexadecimal color code value in the format #xxxxxx.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'The DisplayName parameter specifies the display name for the sensitivity label. The display name appears in the Microsoft Office and is used by Outlook users to select the appropriate sensitivity label before they send a message.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_parentid: {
      type: 'Optional[String]',
      desc: 'The ParentId parameter specifies the parent label that you want this label to be under (a sublabel). You can use any value that uniquely identifies the parent sensitivity label for example name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_advancedsettings: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[Array[String]],
            }]]]',
      desc: 'The AdvancedSettings parameter enables client-specific features and capabilities on the sensitivity label. The settings that you configure with this parameter only affect apps that are designed for the setting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SCLabelSetting[]',
      mof_is_embedded: true,
    },
    dsc_siteandgroupprotectionallowlimitedaccess: {
      type: 'Optional[Boolean]',
      desc: 'The SiteAndGroupProtectionAllowLimitedAccess parameter enables or disables limited access.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applywatermarkingfontname: {
      type: 'Optional[String]',
      desc: 'The ApplyWaterMarkingFontName parameter specifies the font of the watermark text. If the value contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applywatermarkingenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ApplyWaterMarkingEnabled parameter enables or disables the Apply Watermarking Header action for the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingheadertext: {
      type: 'Optional[String]',
      desc: 'The ApplyContentMarkingFooterText parameter specifies the header text. If the value contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_priority: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The Priority parameter specifies a priority value for the sensitivity label that determines the order of label processing. A lower integer value indicates a highter priority.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_encryptionrightsurl: {
      type: 'Optional[String]',
      desc: 'The EncryptionRightsUrl parameter specifies the URL for hold your own key (HYOK) protection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_comment: {
      type: 'Optional[String]',
      desc: 'The Comment parameter specifies an optional comment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteandgroupprotectionallowaccesstoguestusers: {
      type: 'Optional[Boolean]',
      desc: 'The SiteAndGroupProtectionAllowAccessToGuestUsers parameter enables or disables access to guest users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingfooterenabled: {
      type: 'Optional[Boolean]',
      desc: 'The disabled parameter specifies whether to enable or disable the sensitivity label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_localesettings: {
      type: "Optional[Array[Struct[{
              localekey => Optional[String],
              settings => Array[Struct[{
                key => Optional[String],
                value => Optional[Array[String]],
                cim_instance_type => Enum['MSFT_SCLabelSetting']
              }]]
            }]]]",
      desc: 'The LocaleSettings parameter specifies one or more localized label name or label Tooltips in different languages. Regions include all region codes supported in Office Client applications.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SCLabelLocaleSettings[]',
      mof_is_embedded: true,
    },
    dsc_applycontentmarkingfooterfontsize: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The ApplyContentMarkingFooterFontSize parameter specifies the font size (in points) of the footer text.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingheaderfontcolor: {
      type: 'Optional[String]',
      desc: 'The ApplyContentMarkingFooterFontColor parameter specifies the color of the header text. This parameter accepts a hexadecimal color code value in the format #xxxxxx. The default value is #000000.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteandgroupprotectionprivacy: {
      type: "Optional[Enum['Public', 'Private']]",
      desc: 'The SiteAndGroupProtectionPrivacy parameter specifies the privacy level for the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryptionofflineaccessdays: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The EncryptionOfflineAccessDays parameter specifies the number of days that offline access is allowed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingfootertext: {
      type: 'Optional[String]',
      desc: 'The ApplyContentMarkingFooterText parameter specifies the footer text. If the value contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applywatermarkingfontsize: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The ApplyWaterMarkingFontSize parameter specifies the font size (in points) of the watermark text.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_encryptionprotectiontype: {
      type: "Optional[Enum['Template', 'RemoveProtection', 'UserDefined']]",
      desc: 'The EncryptionProtectionType parameter specifies the protection type for encryption.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specify if this rule should exist or not.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryptionenabled: {
      type: 'Optional[Boolean]',
      desc: 'The EncryptionEnabled parameter specifies whether encryption in enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingheaderalignment: {
      type: "Optional[Enum['Left', 'Center', 'Right']]",
      desc: 'The ApplyContentMarkingFooterAlignment parameter specifies the header alignment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disabled: {
      type: 'Optional[Boolean]',
      desc: 'The disabled parameter specifies whether to enable or disable the sensitivity label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tooltip: {
      type: 'Optional[String]',
      desc: "The ToolTip parameter specifies the default tooltip and sensitivity label description that's seen by users. It the value contains spaces, enclose the value in quotation marks.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingheaderenabled: {
      type: 'Optional[Boolean]',
      desc: 'The ApplyContentMarkingHeaderEnabled parameter enables or disables the Apply Content Marking Header action for the label.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingfooteralignment: {
      type: "Optional[Enum['Left', 'Center', 'Right']]",
      desc: 'The ApplyContentMarkingFooterAlignment parameter specifies the footer alignment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryptiondonotforward: {
      type: 'Optional[Boolean]',
      desc: 'The EncryptionDoNotForward parameter specifies whether the Do Not Forward template is applied.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_siteandgroupprotectionallowemailfromguestusers: {
      type: 'Optional[Boolean]',
      desc: 'The SiteAndGroupProtectionAllowEmailFromGuestUsers parameter enables or disables email from guest users.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applywatermarkinglayout: {
      type: "Optional[Enum['Horizontal', 'Diagonal']]",
      desc: 'The ApplyContentMarkingFooterAlignment parameter specifies the header alignment.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingfooterfontcolor: {
      type: 'Optional[String]',
      desc: 'The ApplyContentMarkingFooterFontColor parameter specifies the color of the footer text. This parameter accepts a hexadecimal color code value in the format #xxxxxx. The default value is #000000.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryptionpromptuser: {
      type: 'Optional[Boolean]',
      desc: 'The EncryptionPromptUser parameter specifies whether to set the label with user defined permission in Word, Excel, and PowerPoint.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_siteandgroupprotectionenabled: {
      type: 'Optional[Boolean]',
      desc: 'The SiteAndGroupProtectionEnabled parameter enables or disables the Site and Group Protection action for the labels.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'The Name parameter specifies the unique name for the sensitivity label. The maximum length is 64 characters. If the value contains spaces, enclose the value in quotation marks.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingheadermargin: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'The ApplyContentMarkingFooterMargin parameter specifies the size (in points) of the header margin.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingheaderfontname: {
      type: 'Optional[String]',
      desc: 'The ApplyContentMarkingFooterFontName parameter specifies the font of the header text. If the value contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryptionaiptemplatescopes: {
      type: 'Optional[String]',
      desc: 'The EncryptionAipTemplateScopes parameter specifies that the label is still published and usable in the AIP classic client.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applycontentmarkingfooterfontname: {
      type: 'Optional[String]',
      desc: 'The ApplyContentMarkingFooterFontName parameter specifies the font of the footer text. If the value contains spaces, enclose the value in quotation marks.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryptioncontentexpiredondateindaysornever: {
      type: 'Optional[String]',
      desc: 'The EncryptionContentExpiredOnDateInDaysOrNever parameter specifies when the encrypted content expires. Valid values are integer or never.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_siteandgroupprotectionallowfullaccess: {
      type: 'Optional[Boolean]',
      desc: 'The SiteAndGroupProtectionAllowFullAccess parameter enables or disables full access.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
