require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_sposharingsettings',
  dscmeta_resource_friendly_name: 'SPOSharingSettings',
  dscmeta_resource_name: 'MSFT_SPOSharingSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SPOSharingSettings resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_showeveryoneexceptexternalusersclaim: {
      type: 'Optional[Boolean]',
      desc: 'Enables the administrator to hide the Everyone except external users claim in the People Picker.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requireanonymouslinksexpireindays: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies all anonymous links that have been created (or will be created) will expire after the set number of days.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_sharingcapability: {
      type: "Optional[Enum['ExistingExternalUserSharingOnly', 'ExternalUserAndGuestSharing', 'Disabled', 'ExternalUserSharingOnly']]",
      desc: 'Configures anonymous link types for folders',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_showallusersclaim: {
      type: 'Optional[Boolean]',
      desc: 'Enables the administrator to hide the All Users claim groups in People Picker.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_provisionsharedwitheveryonefolder: {
      type: 'Optional[Boolean]',
      desc: "Creates a Shared with Everyone folder in every user's new OneDrive for Business document library.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for certificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fileanonymouslinktype: {
      type: "Optional[Enum['View', 'Edit']]",
      desc: 'Configures anonymous link types for files',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defaultlinkpermission: {
      type: "Optional[Enum['None', 'View', 'Edit']]",
      desc: 'Specifies the link permission on the tenant level.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the account to authenticate with.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_bccexternalsharinginvitations: {
      type: 'Optional[Boolean]',
      desc: 'When the feature is enabled, all external sharing invitations that are sent will blind copy the e-mail messages listed in the BccExternalSharingsInvitationList.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sharingdomainrestrictionmode: {
      type: "Optional[Enum['None', 'AllowList', 'BlockList']]",
      desc: 'Specifies the external sharing mode for domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "Only accepted value is 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_showeveryoneclaim: {
      type: 'Optional[Boolean]',
      desc: 'Enables the administrator to hide the Everyone claim in the People Picker.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_folderanonymouslinktype: {
      type: "Optional[Enum['View', 'Edit']]",
      desc: 'Configures anonymous link types for folders',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sharingblockeddomainlist: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of email domains that is blocked or prohibited for sharing with the external collaborators. Entry values as an array of domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Active Directory tenant used for authentication. Format contoso.onmicrosoft.com',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_bccexternalsharinginvitationslist: {
      type: 'Optional[String]',
      desc: "Specifies a list of e-mail addresses to be BCC'd when the BCC for External Sharing feature is enabled.Multiple addresses can be specified by creating a comma separated list with no spaces.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_preventexternalusersfromresharing: {
      type: 'Optional[Boolean]',
      desc: 'Allow or deny external users re-sharing',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_defaultsharinglinktype: {
      type: "Optional[Enum['None', 'Direct', 'Internal', 'AnonymousAccess']]",
      desc: "Lets administrators choose what type of link appears is selected in the 'Get a link' sharing dialog box in OneDrive for Business and SharePoint Online",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_notifyownerswhenitemsreshared: {
      type: 'Optional[Boolean]',
      desc: 'When this parameter is set to $true and another user re-shares a document from a userâ??s OneDrive for Business, the OneDrive for Business owner is notified by e-mail.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sharingalloweddomainlist: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of email domains that is allowed for sharing with the external collaborators. Entry values as an array of domains.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_showpeoplepickersuggestionsforguestusers: {
      type: 'Optional[Boolean]',
      desc: 'Enables the administrator to hide the guest users claim in the People Picker.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableguestsigninacceleration: {
      type: 'Optional[Boolean]',
      desc: 'Accelerates guest-enabled site collections as well as member-only site collections when the SignInAccelerationDomain parameter is set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_requireacceptingaccountmatchinvitedaccount: {
      type: 'Optional[Boolean]',
      desc: 'Ensures that an external user can only accept an external sharing invitation with an account matching the invited email address.Administrators who desire increased control over external collaborators should consider enabling this feature. False (default) - When a document is shared with an external user, bob@contoso.com, it can be accepted by any user with access to the invitation link in the original e-mail.True - User must accept this invitation with bob@contoso.com.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
