require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spotenantsettings',
  dscmeta_resource_friendly_name: 'SPOTenantSettings',
  dscmeta_resource_name: 'MSFT_SPOTenantSettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SPOTenantSettings resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_mincompatibilitylevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the lower bound on the compatibility level for new sites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usefindpeopleinpeoplepicker: {
      type: 'Optional[Boolean]',
      desc: "When set to $true, users aren't able to share with security groups or SharePoint groups",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_marknewfilessensitivebydefault: {
      type: "Optional[Enum['AllowExternalSharing', 'BlockExternalSharing']]",
      desc: 'Allow or block external sharing until at least one Office DLP policy scans the content of the file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_conditionalaccesspolicy: {
      type: "Optional[Enum['AllowFullAccess', 'AllowLimitedAccess', 'BlockAccess']]",
      desc: 'Allow or Block Conditional Access Policy on the SharePoint Tenant',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_owneranonymousnotification: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_disabledwebpartids: {
      type: 'Optional[String]',
      desc: 'Provide GUID for the Web Parts that are to be disabled on the Sharepoint Site',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_maxcompatibilitylevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the upper bound on the compatibility level for new sites.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for certificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usepersistentcookiesforexplorerview: {
      type: 'Optional[Boolean]',
      desc: 'Lets SharePoint issue a special cookie that will allow this feature to work even when Keep Me Signed In is not selected.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Active Directory tenant used for authentication. Format contoso.onmicrosoft.com',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_legacyauthprotocolsenabled: {
      type: 'Optional[Boolean]',
      desc: 'Setting this parameter prevents Office clients using non-modern authentication protocols from accessing SharePoint Online resources.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_publiccdnallowedfiletypes: {
      type: 'Optional[String]',
      desc: 'Configure filetypes allowed for PublicCDN',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_notificationsinsharepointenabled: {
      type: 'Optional[Boolean]',
      desc: "When set to $true, users aren't able to share with security groups or SharePoint groups",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "Only accepted value is 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_uservoiceforfeedbackenabled: {
      type: 'Optional[Boolean]',
      desc: 'Allow feedback via UserVoice.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the account to authenticate with.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_publiccdnenabled: {
      type: 'Optional[Boolean]',
      desc: 'Configure PublicCDN',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_filepickerexternalimagesearchenabled: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_officeclientadaldisabled: {
      type: 'Optional[Boolean]',
      desc: 'When set to true this will disable the ability to use Modern Authentication that leverages ADAL across the tenant.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_applyappenforcedrestrictionstoadhocrecipients: {
      type: 'Optional[Boolean]',
      desc: ' ',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchresolveexactemailorupn: {
      type: 'Optional[Boolean]',
      desc: 'Removes the search capability from People Picker. Note, recently resolved names will still appear in the list until browser cache is cleared or expired.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_hidedefaultthemes: {
      type: 'Optional[Boolean]',
      desc: 'Defines if the default themes are visible or hidden',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_signinaccelerationdomain: {
      type: 'Optional[String]',
      desc: 'Specifies the home realm discovery value to be sent to Azure Active Directory (AAD) during the user sign-in process.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_requireacceptingaccountmatchinvitedaccount: {
      type: 'Optional[Boolean]',
      desc: 'DEPRECATED',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
