require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_spouserprofileproperty',
  dscmeta_resource_friendly_name: 'SPOUserProfileProperty',
  dscmeta_resource_name: 'MSFT_SPOUserProfileProperty',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC SPOUserProfileProperty resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_applicationsecret: {
      type: 'Optional[String]',
      desc: 'Secret of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present']]",
      desc: "Only accepted value is 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_username: {
      type: 'String',
      desc: 'Username of the user to configure the profile properties for. E.g. John.Smith@contoso.com',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Name of the Azure Active Directory tenant used for authentication. Format contoso.onmicrosoft.com',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Global Admin.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_properties: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Array of MSFT_SPOUserProfilePropertyInstance representing the profile properties to set.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_SPOUserProfilePropertyInstance[]',
      mof_is_embedded: true,
    },
  },
)
