require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_teamscallingpolicy',
  dscmeta_resource_friendly_name: 'TeamsCallingPolicy',
  dscmeta_resource_name: 'MSFT_TeamsCallingPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC TeamsCallingPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_musiconholdenabledtype: {
      type: "Optional[Enum['Enabled', 'Disabled', 'UserOverride']]",
      desc: 'Setting this parameter allows you to turn on or turn off music on hold when a PSTN caller is placed on hold. It is turned on by default. Valid options are: Enabled, Disabled, UserOverride. For now setting the value to UserOverride is the same as Enabled. This setting does not apply to call park and SLA boss delegate features. Valid options are: Enabled, Disabled, UserOverride.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Teams Calling Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_livecaptionsenabledtypeforcalling: {
      type: "Optional[Enum['DisabledUserOverride', 'Disabled']]",
      desc: 'Determines whether real-time captions are available for the user in Teams meetings. Set this to DisabledUserOverride to allow user to turn on live captions. Set this to Disabled to prohibit.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowcallforwardingtophone: {
      type: 'Optional[Boolean]',
      desc: 'Enables call forwarding or simultaneous ringing of inbound calls to any phone number.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowtranscriptionforcalling: {
      type: 'Optional[Boolean]',
      desc: "Determines whether post-meeting captions and transcriptions are allowed in a user's meetings. Set this to TRUE to allow. Set this to FALSE to prohibit.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowdelegation: {
      type: 'Optional[Boolean]',
      desc: 'Enables inbound calls to be routed to delegates; allows delegates to make outbound calls on behalf of the users for whom they have delegated permissions.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_spamfilteringenabledtype: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: 'Setting this parameter determines whether calls identified as Spam will be rejected or not (probably). Valid options are: Enabled, Disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowcloudrecordingforcalls: {
      type: 'Optional[Boolean]',
      desc: 'Setting this parameter to True will allows 1:1 Calls to be recorded.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_preventtollbypass: {
      type: 'Optional[Boolean]',
      desc: 'Setting this parameter to True will send calls through PSTN and incur charges rather than going through the network and bypassing the tolls.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Teams Global Admin.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowcallforwardingtouser: {
      type: 'Optional[Boolean]',
      desc: 'Enables call forwarding or simultaneous ringing of inbound calls to other users in your tenant.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_busyonbusyenabledtype: {
      type: "Optional[Enum['Enabled', 'Disabled', 'Unanswered']]",
      desc: 'Setting this parameter lets you configure how incoming calls are handled when a user is already in a call or conference or has a call placed on hold. New or incoming calls will be rejected with a busy signal. Valid options are: Enabled, Disabled and Unanswered.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowvoicemail: {
      type: "Optional[Enum['AlwaysEnabled', 'AlwaysDisabled', 'UserOverride']]",
      desc: 'Enables inbound calls to be routed to voice mail. Valid options are: AlwaysEnabled, AlwaysDisabled, UserOverride.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_autoanswerenabledtype: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: 'This setting allows the tenant admin to enable or disable the Auto-Answer setting. Valid options are: Enabled, Disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_safetransferenabled: {
      type: "Optional[Enum['Enabled', 'Disabled', 'UserOverride']]",
      desc: 'This parameter is not available for use. Valid options are: Enabled, Disabled, UserOverride.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowcallgroups: {
      type: 'Optional[Boolean]',
      desc: 'Enables inbound calls to be routed to call groups.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowprivatecalling: {
      type: 'Optional[Boolean]',
      desc: 'Controls all calling capabilities in Teams. Turning this off will turn off all calling functionality in Teams. If you use Skype for Business for calling, this policy will not affect calling functionality in Skype for Business.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policyexists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: 'Identity of the Teams Calling Policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowwebpstncalling: {
      type: 'Optional[Boolean]',
      desc: 'Allows PSTN calling from the Team web client',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
