require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_teamsemergencycallroutingpolicy',
  dscmeta_resource_friendly_name: 'TeamsEmergencyCallRoutingPolicy',
  dscmeta_resource_name: 'MSFT_TeamsEmergencyCallRoutingPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC TeamsEmergencyCallRoutingPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Teams Emergency Call Routing Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_emergencynumbers: {
      type: 'Optional[Array[Struct[{
              onlinepstnusage => Optional[String],
              emergencydialmask => Optional[String],
              emergencydialstring => Optional[String]
            }]]]',
      desc: 'Emergency number(s) associated with the policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_TeamsEmergencyNumber[]',
      mof_is_embedded: true,
    },
    dsc_identity: {
      type: 'String',
      desc: 'Identity of the Teams Emergency Call Routing Policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Teams Admin.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowenhancedemergencyservices: {
      type: 'Optional[Boolean]',
      desc: 'Flag to enable Enhanced Emergency Services',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
