require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_teamsmeetingpolicy',
  dscmeta_resource_friendly_name: 'TeamsMeetingPolicy',
  dscmeta_resource_name: 'MSFT_TeamsMeetingPolicy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC TeamsMeetingPolicy resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_ipaudiomode: {
      type: "Optional[Enum['EnabledOutgoingIncoming', 'Disabled']]",
      desc: 'Determines whether or not a user can use audio in a meeting that supports it.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowusertojoinexternalmeeting: {
      type: "Optional[Enum['Enabled', 'FederatedOnly', 'Disabled']]",
      desc: 'Determines what types of external meetings users can join. Enabled is able join all external meetings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ipvideomode: {
      type: "Optional[Enum['EnabledOutgoingIncoming', 'Disabled']]",
      desc: 'Determines whether or not a user can use video in a meeting that supports it.  Can only be enabled if IPAudioMode is enabled',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enrolluseroverride: {
      type: "Optional[Enum['Disabled', 'Enabled']]",
      desc: 'Determines whether or not users will be able to enroll/capture their Biometric data: Face & Voice.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Description of the Teams Meeting Policy.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: 'Identity of the Teams Meeting Policy.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_designatedpresenterrolemode: {
      type: "Optional[Enum['OrganizerOnlyUserOverride', 'EveryoneInCompanyUserOverride', 'EveryoneUserOverride']]",
      desc: 'Determines if users can change the default value of the Who can present? setting in Meeting options in the Teams client. This policy setting affects all meetings, including Meet Now meetings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowmeetnow: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether a user can start ad-hoc meetings. Set this to TRUE to allow a user to start ad-hoc meetings. Set this to FALSE to prohibit the user from starting ad-hoc meetings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowipaudio: {
      type: 'Optional[Boolean]',
      desc: "Determines whether audio is enabled in a user's meetings or calls. Set this to TRUE to allow the user to share their audioo. Set this to FALSE to prohibit the user from sharing their audio.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowpstnuserstobypasslobby: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether PSTN users should be automatically admitted to the meetings. Set this to TRUE to allow the PSTN user to be able bypass the meetinglobby. Set this to FALSE to prohibit the PSTN user from bypassing the meetinglobby.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowndistreaming: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether a user is able to use NDI (Network Device Interface) in meetings - both for output and input streams.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_autoadmittedusers: {
      type: "Optional[Enum['EveryoneInCompany', 'Everyone', 'EveryoneInSameAndFederatedCompany', 'OrganizerOnly', 'InvitedUsers', 'EveryoneInCompanyExcludingGuests']]",
      desc: "Determines what types of participants will automatically be added to meetings organized by this user. Set this to EveryoneInCompany if you would like meetings to place every external user in the lobby but allow all users in the company to join the meeting immediately. Set this to Everyone if you'd like to admit anonymous users by default. Set this to EveryoneInSameAndFederatedCompany if you would like meetings to allow federated users to join like your company's users, but place all other external users in a lobby. Set this to InvitedUsers if you would like meetings to allow only the invited users.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowoutlookaddin: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether a user can schedule Teams Meetings in Outlook desktop client. Set this to TRUE to allow the user to be able to schedule Teams meetings in Outlook client. Set this to FALSE to prohibit a user from scheduling Teams meeting in Outlook client.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowtranscription: {
      type: 'Optional[Boolean]',
      desc: "Determines whether real-time and/or post-meeting captions and transcriptions are allowed in a user's meetings. Set this to TRUE to allow. Set this to FALSE to prohibit.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowprivatemeetingscheduling: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether a user can schedule private meetings. Set this to TRUE to allow a user to schedule private meetings. Set this to FALSE to prohibit the user from scheduling private meetings. Note this only restricts from scheduling and not from joining a meeting scheduled by another user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_streamingattendeemode: {
      type: "Optional[Enum['Disabled', 'Enabled']]",
      desc: 'Determines whether or not meetings created by users with this policy are able to utilize the meeting overflow capability.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowrecordingstorageoutsideregion: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether cloud recording can be stored out of region for go-local tenants where recording is not yet enabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowexternalparticipantgiverequestcontrol: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether external participants can request or give control of screen sharing during meetings scheduled by this user. Set this to TRUE to allow the user to be able to give or request control. Set this to FALSE to prohibit an external user from giving or requesting control in a meeting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_recordingstoragemode: {
      type: "Optional[Enum['Stream', 'OneDriveForBusiness']]",
      desc: 'Determines whether recordings will be stored in Stream or OneDrive for Business.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Teams Global Admin.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_mediabitratekb: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Determines the media bit rate for audio/video/app sharing transmissions in meetings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_videofiltersmode: {
      type: "Optional[Enum['NoFilters', 'BlurOnly', 'BlurAndDefaultBackgrounds', 'AllFilters']]",
      desc: 'Determines which background filters are available to meeting attendees.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_teamscamerafarendptzmode: {
      type: "Optional[Enum['Disabled', 'Enabled']]",
      desc: 'Determines whether or not meetings created by users with this policy are able to utilize the Camera Far-End PTZ Mode.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowanonymoususerstostartmeeting: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether anonymous users can initiate a meeting. Set this to TRUE to allow anonymous users to initiate a meeting. Set this to FALSE to prohibit them from initiating a meeting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_preferredmeetingproviderforislandsmode: {
      type: "Optional[Enum['TeamsAndSfb', 'Teams']]",
      desc: 'Determines which Outlook Add-in the user will get as preferred Meeting provider(TeamsAndSfb or Teams).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_alloworganizerstooverridelobbysettings: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether organizers can override lobby settings for both VOIP and PSTN. Set this to TRUE to allow. Set this to FALSE to prohibit.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Present ensures the policy exists, absent ensures it is removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowanonymoususerstodialout: {
      type: 'Optional[Boolean]',
      desc: 'CURRENTLY DISABLED: Determines whether anonymous users can use the Call Me At feature for meeting audio.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowbreakoutrooms: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether or not meetings created by users with this policy are able to utilize the Breakout Rooms feature.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowengagementreport: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: 'Determines whether or not a meeting Organizer can track join and leave times for all users within their meetings as well as download a roster.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowmeetingreactions: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether or not meetings created by users with this policy are able to utilize the Meeting Reactions feature.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowprivatemeetnow: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether a user can start private ad-hoc meetings. Set this to TRUE to allow a user to start private ad-hoc meetings. Set this to FALSE to prohibit the user from starting private ad-hoc meetings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_screensharingmode: {
      type: "Optional[Enum['SingleApplication', 'EntireScreen', 'Disabled']]",
      desc: 'Determines the mode in which a user can share a screen in calls or meetings. Set this to SingleApplication to allow the user to share an application at a given point in time. Set this to EntireScreen to allow the user to share anything on their screens. Set this to Disabled to prohibit the user from sharing their screens.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_meetingchatenabledtype: {
      type: "Optional[Enum['Disabled', 'Enabled']]",
      desc: 'Determines whether or not Chat will be enabled or disabled for meetings.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowpowerpointsharing: {
      type: 'Optional[Boolean]',
      desc: "Determines whether Powerpoint sharing is allowed in a user's meetings. Set this to TRUE to allow. Set this to FALSE to prohibit.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowipvideo: {
      type: 'Optional[Boolean]',
      desc: "Determines whether video is enabled in a user's meetings or calls. Set this to TRUE to allow the user to share their video. Set this to FALSE to prohibit the user from sharing their video.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowparticipantgiverequestcontrol: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether participants can request or give control of screen sharing during meetings scheduled by this user. Set this to TRUE to allow the user to be able to give or request control. Set this to FALSE to prohibit the user from giving, requesting control in a meeting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_livecaptionsenabledtype: {
      type: "Optional[Enum['Disabled', 'DisabledUserOverride']]",
      desc: 'Determines whether a user should have the option to view live captions or not in a meeting.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowchannelmeetingscheduling: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether a user can schedule channel meetings. Set this to TRUE to allow a user to schedule channel meetings. Set this to FALSE to prohibit the user from scheduling channel meetings. Note this only restricts from scheduling and not from joining a meeting scheduled by another user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowsharednotes: {
      type: 'Optional[Boolean]',
      desc: 'Determines whether users are allowed to take shared notes. Set this to TRUE to allow. Set this to FALSE to prohibit.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_allowcloudrecording: {
      type: 'Optional[Boolean]',
      desc: "Determines whether cloud recording is allowed in a user's meetings. Set this to TRUE to allow the user to be able to record meetings. Set this to FALSE to prohibit the user from recording meetings.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_roomattributeuseroverride: {
      type: "Optional[Enum['Off', 'Distinguish', 'Attribute']]",
      desc: 'Determines whether or not biometric data will be used to distinguish and or attribute in the transcript.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowwhiteboard: {
      type: 'Optional[Boolean]',
      desc: "Determines whether whiteboard is allowed in a user's meetings. Set this to TRUE to allow. Set this to FALSE to prohibit.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
