require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_exomalwarefilterrule',
  dscmeta_resource_friendly_name: 'EXOMalwareFilterRule',
  dscmeta_resource_name: 'MSFT_EXOMalwareFilterRule',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'Microsoft365DSC',
  dscmeta_module_version: '1.22.105.1',
  docs: 'The DSC EXOMalwareFilterRule resource type.
         Automatically generated from version 1.22.105.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_tenantid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory tenant used for authentication.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_certificatepath: {
      type: 'Optional[String]',
      desc: 'Path to certificate used in service principal usually a PFX file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_priority: {
      type: 'Optional[String]',
      desc: "The Priority parameter specifies a priority value for the rule that determines the order of rule processing. A lower integer value indicates a higher priority, the value 0 is the highest priority, and rules can't have the same priority value.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_malwarefilterpolicy: {
      type: 'Optional[String]',
      desc: 'The MalwareFilterPolicy parameter specifies the malware filter policy to apply to messages that match the conditions defined by this malware filter rule.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_senttomemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The SentToMemberOf parameter specifies a condition that looks for messages sent to members of distribution groups, dynamic distribution groups, or mail-enabled security groups. You can use any value that uniquely identifies the group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_certificatepassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Username can be made up to anything but password will be used for CertificatePassword',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_comments: {
      type: 'Optional[String]',
      desc: "The Comments parameter specifies informative comments for the rule, such as what the rule is used for or how it has changed over time. The length of the comment can't exceed 1024 characters.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies if the Malware Filter Rule should exist.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sentto: {
      type: 'Optional[Array[String]]',
      desc: 'The SentTo parameter specifies a condition that looks for recipients in messages. You can use any value that uniquely identifies the recipient.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_recipientdomainis: {
      type: 'Optional[Array[String]]',
      desc: 'The RecipientDomainIs parameter specifies a condition that looks for recipients with email address in the specified domains. You can specify multiple domains separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_identity: {
      type: 'String',
      desc: 'The Identity parameter specifies the EXO resource you want to modify.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credentials of the Exchange Global Admin',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_exceptifrecipientdomainis: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfRecipientDomainIs parameter specifies an exception that looks for recipients with email address in the specified domains. You can specify multiple domains separated by commas.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_certificatethumbprint: {
      type: 'Optional[String]',
      desc: "Thumbprint of the Azure Active Directory application's authentication certificate to use for authentication.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_applicationid: {
      type: 'Optional[String]',
      desc: 'Id of the Azure Active Directory application to authenticate with.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_exceptifsentto: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSentTo parameter specifies an exception that looks for recipients in messages. You can use any value that uniquely identifies the recipient.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_exceptifsenttomemberof: {
      type: 'Optional[Array[String]]',
      desc: 'The ExceptIfSentToMemberOf parameter specifies an exception that looks for messages sent to members of groups. You can use any value that uniquely identifies the group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: 'Optional[Boolean]',
      desc: 'The Enabled parameter enables or disables the malware filter rule. Valid input for this parameter is $true or $false. The default value is $true.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
